@@ -20,15 +20,14 @@ from flarchitect.authentication.jwt import (
     get_pk_and_lookups,
     refresh_access_token,
 )
+from flarchitect.authentication.token_store import rotate_refresh_token
 from flarchitect.authentication.user import set_current_user
-from flarchitect.core.utils import (
-    get_primary_key_info,
-    get_url_pk,
-)
+from flarchitect.core.utils import get_primary_key_info, get_url_pk
 from flarchitect.database.operations import CrudService
 from flarchitect.database.utils import get_models_relationships, get_primary_keys
 from flarchitect.exceptions import CustomHTTPException, handle_http_exception
 from flarchitect.logging import logger
+from flarchitect.plugins import PluginManager
 from flarchitect.schemas.auth import LoginSchema, RefreshSchema, TokenSchema
 from flarchitect.schemas.utils import get_input_output_from_model_or_make
 from flarchitect.specs.utils import (
@@ -40,7 +39,8 @@ from flarchitect.specs.utils import (
     get_tag_group,
 )
 from flarchitect.utils.config_helpers import get_config_or_model_meta
-from flarchitect.utils.general import AttributeInitializerMixin
+from flarchitect.utils.core_utils import convert_case
+from flarchitect.utils.general import AttributeInitialiserMixin
 from flarchitect.utils.response_helpers import create_response
 from flarchitect.utils.session import get_session
 
@@ -48,6 +48,162 @@ if TYPE_CHECKING:
     from flarchitect import Architect
 
 
+def _global_pre_process(service: CrudService, global_pre_hook: Callable | None, **hook_kwargs: Any) -> dict[str, Any]:
+    """Execute the global pre-hook if defined, seeding default model.
+
+    Args:
+        service (CrudService): CRUD service supplying default model.
+        global_pre_hook (Callable | None): Hook to run before any processing.
+        **hook_kwargs (Any): Keyword arguments passed to the hook.
+
+    Returns:
+        dict[str, Any]: Possibly modified hook arguments.
+    """
+    if global_pre_hook:
+        model = hook_kwargs.pop("model", None) or service.model
+        return global_pre_hook(model=model, **hook_kwargs)
+    return hook_kwargs
+
+
+def _pre_process(service: CrudService, pre_hook: Callable | None, **hook_kwargs: Any) -> dict[str, Any]:
+    """Run the pre-hook allowing mutation of incoming arguments.
+
+    Args:
+        service (CrudService): CRUD service supplying default model.
+        pre_hook (Callable | None): Hook executed before the action.
+        **hook_kwargs (Any): Keyword arguments passed to the hook.
+
+    Returns:
+        dict[str, Any]: Processed hook arguments.
+    """
+    if pre_hook:
+        model = hook_kwargs.pop("model", None) or service.model
+        return pre_hook(model=model, **hook_kwargs)
+    return hook_kwargs
+
+
+def _post_process(service: CrudService, post_hook: Callable | None, output: Any, **hook_kwargs: Any) -> Any:
+    """Apply a post-hook to the action result.
+
+    Args:
+        service (CrudService): CRUD service supplying default model.
+        post_hook (Callable | None): Hook executed after the action.
+        output (Any): Data returned from the action.
+        **hook_kwargs (Any): Keyword arguments passed to the hook.
+
+    Returns:
+        Any: Final output after post processing.
+    """
+    if post_hook:
+        model = hook_kwargs.pop("model", None) or service.model
+        out_val = post_hook(model=model, output=output, **hook_kwargs).get("output")
+        return out_val.get("output") if isinstance(out_val, dict) and "output" in out_val else out_val
+    return output
+
+
+def _route_function_factory(
+    service: CrudService,
+    action: Callable,
+    many: bool,
+    global_pre_hook: Callable | None,
+    pre_hook: Callable | None,
+    post_hook: Callable | None,
+    get_field: str | None,
+    join_model: type[DeclarativeBase] | None,
+    output_schema: Schema | None,
+    http_method: str = "GET",
+    plugins: PluginManager | None = None,
+) -> Callable:
+    """Construct the route function tying together hooks and action.
+
+    Args:
+        service (CrudService): CRUD service for the model.
+        action (Callable): CRUD operation to execute.
+        many (bool): Whether multiple records are expected.
+        global_pre_hook (Callable | None): Global pre-hook.
+        pre_hook (Callable | None): Pre-hook.
+        post_hook (Callable | None): Post-hook.
+        get_field (str | None): Field used for lookups.
+        join_model (type[DeclarativeBase] | None): Related model for joins.
+        output_schema (Schema | None): Schema used for output serialisation.
+
+    Returns:
+        Callable: Configured Flask route function.
+    """
+
+    def route_function(id: int | None = None, **hook_kwargs: Any) -> Any:
+        # Plugin pre-hook
+        if plugins:
+            ctx = {
+                "model": service.model,
+                "method": http_method,
+                "many": many,
+                "id": id,
+                "field": get_field,
+                "join_model": join_model,
+                "output_schema": output_schema,
+            }
+            upd = plugins.before_model_op(ctx | hook_kwargs)
+            if isinstance(upd, dict):
+                hook_kwargs.update(upd)
+
+        pre_kwargs = dict(hook_kwargs)
+        pre_kwargs.setdefault("id", id)
+        pre_kwargs.setdefault("field", get_field)
+        pre_kwargs.setdefault("join_model", join_model)
+        pre_kwargs.setdefault("output_schema", output_schema)
+        hook_kwargs = _global_pre_process(
+            service,
+            global_pre_hook,
+            **pre_kwargs,
+        )
+        hook_kwargs = _pre_process(service, pre_hook, **hook_kwargs)
+        action_kwargs: dict[str, Any] = {"lookup_val": id} if id else {}
+        action_kwargs.update(hook_kwargs)
+        action_kwargs["many"] = many
+        action_kwargs["data_dict"] = hook_kwargs.get("deserialized_data")
+        action_kwargs["join_model"] = hook_kwargs.get("join_model")
+        action_kwargs["id"] = hook_kwargs.get("id")
+        action_kwargs["model"] = hook_kwargs.get("model")
+
+        output = action(**action_kwargs) or abort(404)
+        final_output = _post_process(service, post_hook, output, **hook_kwargs)
+
+        # Plugin post-hook
+        if plugins:
+            ctx_after = {
+                "model": hook_kwargs.get("model", service.model),
+                "method": http_method,
+                "many": many,
+                "id": id,
+                "field": get_field,
+                "join_model": join_model,
+                "output_schema": output_schema,
+            }
+            maybe = plugins.after_model_op(ctx_after | hook_kwargs, final_output)
+            if maybe is not None:
+                final_output = maybe
+
+        # Attempt to broadcast change events to WS subscribers
+        try:
+            from flarchitect.core.websockets import broadcast_change
+
+            broadcast_change(
+                model=hook_kwargs.get("model", service.model),
+                method=http_method,
+                payload=final_output,
+                id=id,
+                many=many,
+            )
+        except Exception:
+            # best-effort; broadcasting should never break the response
+            pass
+
+        return final_output
+
+    return route_function
+
+
 def create_params_from_rule(model: DeclarativeBase, rule, schema: Schema) -> list[dict[str, Any]]:
     """Generates path parameters from a Flask routing rule.
 
@@ -65,6 +221,10 @@ def create_params_from_rule(model: DeclarativeBase, rule, schema: Schema) -> lis
         name = get_config_or_model_meta("name", model=model, output_schema=schema, default=None)
         if not name:
             name = (model or schema).__name__.replace("Schema", "").replace("schema", "")
+        name = convert_case(
+            name,
+            get_config_or_model_meta("API_SCHEMA_CASE", model=model, default="camel"),
+        )
 
         param_info = {
             "name": argument,
@@ -153,61 +313,6 @@ def create_route_function(
     Returns:
         Callable: The route function.
     """
-
-    def global_pre_process(global_pre_hook: Callable, **hook_kwargs) -> dict[str, Any]:
-        if global_pre_hook:
-            model = hook_kwargs.pop("model", None) or service.model
-
-            return global_pre_hook(model=model, **hook_kwargs)
-        return hook_kwargs
-
-    def pre_process(pre_hook: Callable, **hook_kwargs) -> dict[str, Any]:
-        if pre_hook:
-            model = hook_kwargs.pop("model", None) or service.model
-
-            return pre_hook(model=model, **hook_kwargs)
-        return hook_kwargs
-
-    def post_process(post_hook: Callable, output: Any, **hook_kwargs) -> Any:
-        if post_hook:
-            model = hook_kwargs.pop("model", None) or service.model
-            out_val = post_hook(model=model, output=output, **hook_kwargs).get("output")
-
-            # Ensure out_val is valid before attempting to access "output"
-            return out_val.get("output") if isinstance(out_val, dict) and "output" in out_val else out_val
-
-        return output
-
-    def route_function_factory(
-        action: Callable,
-        many: bool,
-        global_pre_hook: Callable | None,
-        pre_hook: Callable | None,
-        post_hook: Callable | None,
-    ) -> Callable:
-        def route_function(id: int | None = None, **hook_kwargs) -> Any:
-            hook_kwargs = global_pre_process(
-                global_pre_hook,
-                id=id,
-                field=get_field,
-                join_model=join_model,
-                output_schema=kwargs.get("output_schema"),
-                **hook_kwargs,
-            )
-            hook_kwargs = pre_process(pre_hook, **hook_kwargs)
-            action_kwargs = {"lookup_val": id} if id else {}
-            action_kwargs.update(hook_kwargs)
-            action_kwargs["many"] = many
-            action_kwargs["data_dict"] = hook_kwargs.get("deserialized_data")
-            action_kwargs["join_model"] = hook_kwargs.get("join_model")
-            action_kwargs["id"] = hook_kwargs.get("id")
-            action_kwargs["model"] = hook_kwargs.get("model")
-
-            output = action(**action_kwargs) or abort(404)
-            return post_process(post_hook, output, **hook_kwargs)
-
-        return route_function
-
     global_pre_hook = get_config_or_model_meta("API_GLOBAL_SETUP_CALLBACK", default=None, method=method)
     pre_hook = get_config_or_model_meta("API_SETUP_CALLBACK", model=service.model, default=None, method=method)
     post_hook = get_config_or_model_meta("API_RETURN_CALLBACK", model=service.model, default=None, method=method)
@@ -220,10 +325,40 @@ def create_route_function(
     }
 
     action = action_map.get(method)
-    return route_function_factory(action, many, global_pre_hook, pre_hook, post_hook)
+    return _route_function_factory(
+        service,
+        action,
+        many,
+        global_pre_hook,
+        pre_hook,
+        post_hook,
+        get_field,
+        join_model,
+        kwargs.get("output_schema"),
+        method,
+        plugins=kwargs.get("plugins"),
+    )
 
 
-class RouteCreator(AttributeInitializerMixin):
+class RouteCreator(AttributeInitialiserMixin):
+    """Automatically construct API routes for configured models.
+
+    RouteCreator inspects SQLAlchemy models and their associated schemas to
+    generate CRUD endpoints. When ``api_full_auto`` is ``True``, initialisation
+    triggers model setup, configuration validation, and registration of the
+    generated routes on the application blueprint.
+
+    Attributes:
+        created_routes: Mapping of endpoint names to route metadata.
+        architect: Parent Architect supplying the Flask application.
+        api_full_auto: Enables automatic route generation during initialisation.
+        api_base_model: Base model or models used to discover resources.
+        api_base_schema: Default schema used for serialisation.
+        db_service: CRUD service class used for database interactions.
+        session: SQLAlchemy session or sessions bound to the models.
+        blueprint: Flask blueprint where generated routes are registered.
+    """
+
     created_routes: dict[str, dict[str, Any]] | None = None
     architect: Architect
     api_full_auto: bool | None = True
@@ -234,7 +369,7 @@ class RouteCreator(AttributeInitializerMixin):
     blueprint: Blueprint | None = None
 
     def __init__(self, architect: Architect, *args, **kwargs):
-        """Initialize the RouteCreator object.
+        """Initialise the RouteCreator object.
 
         Args:
             architect (Architect): The architect object.
@@ -274,9 +409,12 @@ class RouteCreator(AttributeInitializerMixin):
 
         for base in self.api_base_model:
             try:
-                get_session(base)
+                with get_session(base):
+                    pass
             except Exception as exc:  # pragma: no cover - configuration error
-                raise ValueError("If FULL_AUTO is True, API_BASE_MODEL must be bound to a SQLAlchemy session.") from exc
+                raise ValueError(
+                    "If FULL_AUTO is True, API_BASE_MODEL must be bound to a SQLAlchemy session.",
+                ) from exc
 
     def _validate_authentication_setup(self):
         """Validate the authentication setup for the API."""
@@ -346,6 +484,14 @@ class RouteCreator(AttributeInitializerMixin):
         self.architect.app.register_blueprint(self.blueprint)
 
     def make_exception_routes(self):
+        """Register error handlers for standard and custom HTTP exceptions."""
+
+        logger.debug(
+            4,
+            "Setting up custom error handler for CustomHTTPException.",
+        )
+        self.architect.app.register_error_handler(CustomHTTPException, handle_http_exception)
+
         for code in default_exceptions:
             logger.debug(
                 4,
@@ -358,14 +504,91 @@ class RouteCreator(AttributeInitializerMixin):
         for base in self.api_base_model:
             for model_class in base.__subclasses__():
                 if hasattr(model_class, "__table__") and hasattr(model_class, "Meta"):
-                    session = get_session(model_class)
-                    self.make_all_model_routes(model_class, session)
+                    with get_session(model_class) as session:
+                        self.make_all_model_routes(model_class, session)
                 else:
                     logger.debug(
                         4,
                         f"Skipping model |{model_class.__name__}| because it does not have a table or Meta class.",
                     )
 
+    # ----- Roles resolution helpers -----
+    def _normalize_roles_spec(self, spec: Any, default_any_of: bool = False) -> tuple[list[str] | None, bool]:
+        """Normalise a roles specification to a concrete list and any_of flag.
+
+        Args:
+            spec: Roles definition which may be a list/tuple/str/dict/bool.
+            default_any_of: Fallback for ``any_of`` when not declared.
+
+        Returns:
+            Tuple of (roles list or None, any_of flag).
+        """
+        if spec is None:
+            return None, False
+        if spec is True:
+            # True means "auth only"; we don't attach a role decorator
+            return None, default_any_of
+        if isinstance(spec, list | tuple):
+            return list(spec), default_any_of
+        if isinstance(spec, str):
+            return [spec], default_any_of
+        if isinstance(spec, dict):
+            roles = spec.get("roles", [])
+            any_of = bool(spec.get("any_of", default_any_of))
+            if isinstance(roles, str):
+                roles = [roles]
+            if isinstance(roles, list | tuple) and roles:
+                return list(roles), any_of
+            return None, any_of
+        return None, default_any_of
+
+    def _resolve_roles_for_route(
+        self,
+        *,
+        model: Callable | None,
+        http_method: str,
+        is_many: bool = False,
+        is_relation: bool = False,
+    ) -> tuple[list[str] | None, bool]:
+        """Resolve roles and any_of for a specific route from config/metadata.
+
+        Order of precedence:
+        1) ``API_ROLE_MAP`` (dict or list/str) on model or app config.
+           - Keys checked in order: relation-specific → GET granularity → method → ALL → *
+           - Values can be list[str], str, or {roles: [...], any_of: bool}.
+        2) ``API_ROLES_REQUIRED`` (list) → all-of semantics.
+        3) ``API_ROLES_ACCEPTED`` (list) → any-of semantics.
+        """
+        role_map = get_config_or_model_meta("API_ROLE_MAP", model=model, default=None)
+        if role_map is not None:
+            keys: list[str] = []
+            method = http_method.upper()
+            if is_relation:
+                keys.append(f"RELATION_{method}")
+                if method == "GET":
+                    keys.append("RELATION_GET_MANY" if is_many else "RELATION_GET_ONE")
+            if method == "GET":
+                keys.append("GET_MANY" if is_many else "GET_ONE")
+            keys.append(method)
+            keys.extend(["ALL", "*"])
+
+        if isinstance(role_map, dict):
+            for k in keys:
+                if k in role_map:
+                    return self._normalize_roles_spec(role_map[k])
+        else:
+            return self._normalize_roles_spec(role_map)
+
+        required = get_config_or_model_meta("API_ROLES_REQUIRED", model=model, default=None)
+        if required is not None:
+            return self._normalize_roles_spec(required, default_any_of=False)
+
+        accepted = get_config_or_model_meta("API_ROLES_ACCEPTED", model=model, default=None)
+        if accepted is not None:
+            return self._normalize_roles_spec(accepted, default_any_of=True)
+
+        return None, False
+
     def make_auth_routes(self):
         """Create the authentication routes for the API."""
         auth_method = get_config_or_model_meta("API_AUTHENTICATE_METHOD", default=None)
@@ -407,7 +630,11 @@ class RouteCreator(AttributeInitializerMixin):
             try:
                 encoded = auth_header.split(" ", 1)[1]
                 username, password = base64.b64decode(encoded).decode("utf-8").split(":", 1)
-            except (ValueError, binascii.Error, UnicodeDecodeError):  # pragma: no cover - bad header
+            except (
+                ValueError,
+                binascii.Error,
+                UnicodeDecodeError,
+            ):  # pragma: no cover - bad header
                 return create_response(status=401, errors={"error": "Invalid credentials"})
 
             lookup_field = get_config_or_model_meta("API_USER_LOOKUP_FIELD", model=user, default=None)
@@ -421,11 +648,14 @@ class RouteCreator(AttributeInitializerMixin):
             return create_response(status=401, errors={"error": "Invalid credentials"})
 
     def _make_api_key_auth_routes(self, user: Callable) -> None:
-        """Create API key authentication login route.
+        """Register the API key authentication login endpoint.
 
-        The route expects an ``Authorization`` header using the ``Api-Key``
-        scheme. The provided key is validated against the configured user
-        model and, upon success, basic user information is returned.
+        Args:
+            user (Callable): User model containing credential fields and
+                verification methods.
+
+        Returns:
+            None: The login route is attached to the Flask application.
         """
 
         @self.architect.app.route("/auth/login", methods=["POST"])
@@ -443,14 +673,18 @@ class RouteCreator(AttributeInitializerMixin):
                 check_method = get_config_or_model_meta("API_CREDENTIAL_CHECK_METHOD", model=user, default=None)
 
                 query = getattr(user, "query", None)
+                usr = None
                 if query is None:
                     try:
-                        session = get_session(user)
-                        query = session.query(user)
+                        with get_session(user) as session:
+                            for candidate in session.query(user).all():
+                                stored = getattr(candidate, hash_field, None)
+                                if stored and getattr(candidate, check_method)(token):
+                                    usr = candidate
+                                    break
                     except Exception:
-                        query = None
-                usr = None
-                if query is not None:
+                        usr = None
+                else:
                     for candidate in query.all():
                         stored = getattr(candidate, hash_field, None)
                         if stored and getattr(candidate, check_method)(token):
@@ -466,14 +700,30 @@ class RouteCreator(AttributeInitializerMixin):
 
             return create_response(status=401, errors={"error": "Invalid credentials"})
 
-    def _make_jwt_auth_routes(self, user: Callable):
-        """Create JWT authentication routes."""
+    def _make_jwt_auth_routes(self, user: Callable) -> None:
+        """Register JWT login, logout, and refresh endpoints.
+
+        Args:
+            user (Callable): User model used for credential verification and
+                token generation.
+
+        Returns:
+            None: Routes are added to the Flask application.
+        """
         self._create_jwt_login_route(user)
         self._create_jwt_logout_route(user)
         self._create_jwt_refresh_route(user)
 
-    def _create_jwt_login_route(self, user: Callable):
-        """Create the login route for JWT authentication."""
+    def _create_jwt_login_route(self, user: Callable) -> None:
+        """Create the login route for JWT authentication.
+
+        Args:
+            user (Callable): User model that provides credential lookup and
+                verification methods.
+
+        Returns:
+            None: The login route is registered on the Flask application.
+        """
 
         @self.architect.app.route("/auth/login", methods=["POST"])
         @self.architect.schema_constructor(
@@ -483,9 +733,13 @@ class RouteCreator(AttributeInitializerMixin):
             many=False,
             roles=True,
             group_tag="Authentication",
+            tag="Authentication",
+            summary="Authenticate user and return JWT tokens.",
             auth=False,
         )
         def login(*args, **kwargs):
+            """Authenticate a user and return JWT tokens."""
+
             data = request.get_json()
             username = data.get("username")
             password = data.get("password")
@@ -511,21 +765,40 @@ class RouteCreator(AttributeInitializerMixin):
 
             raise CustomHTTPException(401, "Invalid credentials")
 
-    def _create_jwt_logout_route(self, user: Callable):
-        """Create the logout route for JWT authentication."""
+    def _create_jwt_logout_route(self, user: Callable) -> None:
+        """Create the logout route for JWT authentication.
+
+        Args:
+            user (Callable): User model, included for interface consistency.
+
+        Returns:
+            None: The logout route is registered on the Flask application.
+        """
 
         @self.architect.app.route("/auth/logout", methods=["POST"])
         @self.architect.schema_constructor(
             output_schema=None,
             many=False,
             group_tag="Authentication",
+            tag="Authentication",
+            summary="Log out current user.",
         )
         def logout(*args, **kwargs):
+            """Log out the current user."""
+
             set_current_user(None)
             return {}
 
-    def _create_jwt_refresh_route(self, *args, **kwargs):
-        """Create the refresh token route for JWT authentication."""
+    def _create_jwt_refresh_route(self, user: Callable) -> None:
+        """Create the refresh token route for JWT authentication.
+
+        Args:
+            user (Callable): User model, currently unused but kept for API
+                symmetry with other JWT route creators.
+
+        Returns:
+            None: The refresh route is registered on the Flask application.
+        """
 
         @self.architect.app.route("/auth/refresh", methods=["POST"])
         @self.architect.schema_constructor(
@@ -533,21 +806,18 @@ class RouteCreator(AttributeInitializerMixin):
             output_schema=TokenSchema,
             many=False,
             group_tag="Authentication",
+            tag="Authentication",
+            summary="Refresh access token.",
             auth=False,
         )
         def refresh(*args, **kwargs):
-            """
-            Endpoint to refresh JWT access tokens using a refresh token.
-
-            Expects:
-                JSON payload with 'refresh_token'.
-
-            Returns:
-                JSON response with 'access_token' and 'refresh_token'.
-            """
+            """Refresh a JWT access token using a refresh token."""
 
             # Extract the refresh token from the request
             refresh_token = request.get_json().get("refresh_token")
+            # Normalise in case clients send "Bearer <token>" in the payload
+            if isinstance(refresh_token, str) and refresh_token.lower().startswith("bearer "):
+                refresh_token = refresh_token.split(" ", 1)[1].strip()
             if not refresh_token:
                 raise CustomHTTPException(status_code=400, reason="Refresh token is missing")
 
@@ -558,8 +828,12 @@ class RouteCreator(AttributeInitializerMixin):
                 # Let your application's error handlers manage the response
                 raise e
 
-            # Generate a new refresh token
+            # Generate a new refresh token and rotate the old one (single-use)
             new_refresh_token = generate_refresh_token(user)
+            import contextlib
+            with contextlib.suppress(Exception):
+                # Rotation is best-effort; failure should not expose the old token
+                rotate_refresh_token(refresh_token, new_refresh_token)
 
             pk, lookup_field = get_pk_and_lookups()
             # Return the new tokens
@@ -578,22 +852,28 @@ class RouteCreator(AttributeInitializerMixin):
         def before_request(*args, **kwargs):
             g.start_time = time.time()
 
-    def make_all_model_routes(self, model: Callable, session: Any):
+    def make_all_model_routes(self, model: Callable, session: Any) -> None:
         """Create all routes for a given model.
 
         Args:
             model (Callable): The model to create routes for.
-            session (Any): The database session to use for the model.
+            session (Any): Database session used for operations on the model.
+
+        Returns:
+            None: Routes for the model and its relations are registered.
         """
         self._generate_relation_routes(model, session)
         self._generate_model_routes(model, session)
 
-    def _generate_model_routes(self, model: Callable, session: Any):
+    def _generate_model_routes(self, model: Callable, session: Any) -> None:
         """Generate CRUD routes for a model.
 
         Args:
             model (Callable): The model to create routes for.
-            session (Any): The database session to use for the model.
+            session (Any): Database session to use for the model.
+
+        Returns:
+            None: CRUD endpoints are generated for the provided model.
         """
 
         # Retrieve allowed and blocked methods from configuration or model metadata
@@ -637,12 +917,15 @@ class RouteCreator(AttributeInitializerMixin):
             route_data = self._prepare_route_data(model, session, http_method)
             self.generate_route(**route_data)
 
-    def _generate_relation_routes(self, model: Callable, session: Any):
+    def _generate_relation_routes(self, model: Callable, session: Any) -> None:
         """Generate routes for model relationships if configured.
 
         Args:
             model (Callable): The model to create relation routes for.
-            session (Any): The database session to use for the model.
+            session (Any): Database session to use for the model.
+
+        Returns:
+            None: Relation endpoints are generated when enabled.
         """
         if get_config_or_model_meta("API_ADD_RELATIONS", model=model, default=True):
             relations = get_models_relationships(model)
@@ -650,11 +933,15 @@ class RouteCreator(AttributeInitializerMixin):
                 prepared_relation_data = self._prepare_relation_route_data(relation_data, session)
                 self._create_relation_route_and_to_url_function(prepared_relation_data)
 
-    def _create_relation_route_and_to_url_function(self, relation_data: dict[str, Any]):
-        """Create a route for a relation and add a to_url function to the model.
+    def _create_relation_route_and_to_url_function(self, relation_data: dict[str, Any]) -> None:
+        """Create a route for a relation and attach a ``to_url`` helper.
 
         Args:
-            relation_data (Dict[str, Any]): The data for creating the relation route.
+            relation_data (dict[str, Any]): Data describing the relation,
+                including models and join keys.
+
+        Returns:
+            None: The route is registered and helper added to the child model.
         """
         child = relation_data["child_model"]
         parent = relation_data["parent_model"]
@@ -692,6 +979,14 @@ class RouteCreator(AttributeInitializerMixin):
             f"Collecting main model data for --{model.__name__}-- with expected url |{method}|:`{base_url}`.",
         )
 
+        # Resolve roles config for this route
+        roles_list, roles_any_of = self._resolve_roles_for_route(
+            model=model,
+            http_method=http_method,
+            is_many=many,
+            is_relation=False,
+        )
+
         return {
             "model": model,
             "many": many,
@@ -701,6 +996,9 @@ class RouteCreator(AttributeInitializerMixin):
             "output_schema": output_schema_class,
             "session": session,
             "input_schema": (input_schema_class if http_method in ["POST", "PATCH"] else None),
+            # Attach roles for schema_constructor if configured
+            "roles": roles_list if roles_list else False,
+            "roles_any_of": roles_any_of if roles_list else False,
         }
 
     def _prepare_relation_route_data(self, relation_data: dict[str, Any], session: Any) -> dict[str, Any]:
@@ -731,6 +1029,14 @@ class RouteCreator(AttributeInitializerMixin):
             f"Collecting parent/child model relationship for --{parent_model.__name__}-- and --{child_model.__name__}-- with expected url `{relation_url}`.",
         )
 
+        # Resolve roles for relation route (child inherits role policy by default)
+        roles_list, roles_any_of = self._resolve_roles_for_route(
+            model=child_model,
+            http_method="GET",
+            is_many=(relation_data["join_type"][-4:].lower() == "many" or relation_data.get("many", False)),
+            is_relation=True,
+        )
+
         return {
             "child_model": child_model,
             "model": child_model,
@@ -743,6 +1049,9 @@ class RouteCreator(AttributeInitializerMixin):
             "join_key": relation_data["right_column"],
             "output_schema": output_schema_class,
             "session": session,
+            # Attach roles for schema_constructor if configured
+            "roles": roles_list if roles_list else False,
+            "roles_any_of": roles_any_of if roles_list else False,
         }
 
     def generate_route(self, **kwargs: dict[str, Any]):
@@ -767,6 +1076,7 @@ class RouteCreator(AttributeInitializerMixin):
             join_model=kwargs.get("parent_model"),
             get_field=kwargs.get("join_key"),
             output_schema=kwargs.get("output_schema"),
+            plugins=self.architect.plugins,
         )
 
         unique_route_function = self._create_unique_route_function(
