@@ -8,10 +8,7 @@ from sqlalchemy.orm import DeclarativeBase, Query, Session, object_session
 from sqlalchemy.orm.exc import UnmappedInstanceError
 
 from flarchitect.core.utils import get_primary_key_info
-from flarchitect.database.inspections import (
-    get_model_columns,
-    get_model_relationships,
-)
+from flarchitect.database.inspections import get_model_columns, get_model_relationships
 from flarchitect.database.utils import (
     AGGREGATE_FUNCS,
     create_aggregate_conditions,
@@ -117,7 +114,7 @@ def apply_sorting_to_query(args_dict: dict[str, str | int], query: Query, base_m
 
 class CrudService:
     def __init__(self, model: Callable, session: Session):
-        """Initializes the CrudService instance.
+        """Initialises the CrudService instance.
 
         Args:
             model (Callable): SQLAlchemy model class for CRUD operations.
@@ -223,7 +220,7 @@ class CrudService:
         elif select_fields:
             query = query.with_entities(*select_fields)
 
-        if conditions and get_config_or_model_meta("API_ALLOW_FILTER", model=self.model, default=True):
+        if conditions and get_config_or_model_meta("API_ALLOW_FILTERS", model=self.model, default=True):
             query = query.filter(and_(*conditions))
 
         if group_by_fields:
@@ -352,7 +349,7 @@ class CrudService:
         paginated_query, default_pagination_size = paginate_query(filtered_query, args_dict.get("page", 1), args_dict.get("limit"))
 
         return {
-            "query": (paginated_query.all() if hasattr(paginated_query, "all") else paginated_query.items if hasattr(paginated_query, "items") else paginated_query),
+            "query": (paginated_query.all() if hasattr(paginated_query, "all") else (paginated_query.items if hasattr(paginated_query, "items") else paginated_query)),
             "limit": (int(args_dict.get("limit")) if args_dict.get("limit") else default_pagination_size),
             "page": int(args_dict.get("page")) if args_dict.get("page") else 1,
             "total_count": count,
@@ -480,15 +477,19 @@ class CrudService:
 
 
 def recursive_delete(obj, cascade_delete=True, visited=None, objects_touched=None, parent=None):
-    """
-    Recursively delete related objects based on foreign key constraints, optimized for performance.
+    """Recursively delete related objects following foreign key constraints.
+
+    Why/How:
+        Traverses relationships to remove dependent records when permitted.
+        Tracks visited instances to avoid cycles and redundant operations,
+        reducing database round‑trips on complex graphs.
 
     Args:
         obj: The SQLAlchemy model instance to delete.
         cascade_delete (bool): Whether to recursively delete related objects.
-        visited (set): Set of visited objects (identified by their class and primary keys) to avoid redundant deletion.
-        objects_touched (list): List of objects touched (deleted) during the recursive process.
-        parent: The parent object of the current recursion step, used to prevent backward traversal in cyclic relationships.
+        visited (set): Set of visited objects (by class and primary keys) to avoid redundant deletion.
+        objects_touched (list): Objects deleted during the recursion (for diagnostics).
+        parent: Parent object of the current step to prevent backward traversal in cyclic relationships.
     """
 
     def get_obj_id(obj):
