@@ -46,32 +46,38 @@ OTHER_FUNCTIONS = ["groupby", "fields", "join", "orderby"]
 
 
 def fetch_related_classes_and_attributes(model: object) -> list[tuple[str, str]]:
-    """Retrieve related class names and attributes for a given SQLAlchemy model.
+    """Collect relationship attributes and their related class names.
 
     Args:
-        model (object): The SQLAlchemy model class to inspect.
+        model (object): SQLAlchemy declarative model whose relationships are
+            inspected.
 
     Returns:
-        List[Tuple[str, str]]: A list of tuples containing the relationship's
-                               attribute name on the model and the class name of the related model.
+        list[tuple[str, str]]: Pairs of the relationship attribute name on
+        ``model`` and the related model's class name. Returns an empty list if
+        ``model`` defines no relationships.
     """
+
     return [(relation.key, relation.mapper.class_.__name__) for relation in class_mapper(model).relationships]
 
 
 def get_all_columns_and_hybrids(model: DeclarativeBase, join_models: dict[str, DeclarativeBase]) -> tuple[dict[str, dict[str, hybrid_property | InstrumentedAttribute]], list[DeclarativeBase]]:
-    """
-    Retrieves all columns and hybrid properties from the base model and any join models.
+    """Gather columns and hybrid properties for the base and join models.
 
     Args:
-        model (DeclarativeBase): The base SQLAlchemy model.
-        join_models (Dict[str, DeclarativeBase]): Dictionary of join models.
+        model (DeclarativeBase): Base SQLAlchemy model.
+        join_models (dict[str, DeclarativeBase]): Mapping of join model aliases
+            to SQLAlchemy model classes. May be empty.
 
     Returns:
-        Tuple[Dict[str, Dict[str, Union[hybrid_property, InstrumentedAttribute]]], List[DeclarativeBase]]:
-        A tuple containing a dictionary of all columns and a list of all models.
-    """
-    from flarchitect.utils.general import get_config_or_model_meta
+        tuple[dict[str, dict[str, hybrid_property | InstrumentedAttribute]], list[DeclarativeBase]]:
+        A mapping of table names to their public columns/hybrid properties and a
+        list of all models inspected.
 
+    Notes:
+        Attributes beginning with ``_`` are ignored when
+        ``API_IGNORE_UNDERSCORE_ATTRIBUTES`` is set (default).
+    """
     ignore_underscore = get_config_or_model_meta(key="API_IGNORE_UNDERSCORE_ATTRIBUTES", model=model, default=True)
     schema_case = get_config_or_model_meta(key="API_SCHEMA_CASE", model=model, default="camel")
 
@@ -87,7 +93,14 @@ def get_all_columns_and_hybrids(model: DeclarativeBase, join_models: dict[str, D
     return all_columns, all_models
 
 
-def create_pagination_defaults():
+def create_pagination_defaults() -> tuple[dict[str, int], dict[str, int]]:
+    """Assemble default and maximum pagination limits and return both dictionaries.
+
+    Returns:
+        tuple[dict[str, int], dict[str, int]]: Default pagination values and
+        their maximum allowable limits.
+    """
+
     PAGINATION_DEFAULTS = {
         "page": 1,
         "limit": get_config_or_model_meta("API_PAGINATION_SIZE_DEFAULT", default=20),
@@ -100,21 +113,23 @@ def create_pagination_defaults():
 
 
 def extract_pagination_params(args_dict: dict[str, str]) -> tuple[int, int]:
-    """
-    Get the pagination from the request arguments.
+    """Parse pagination information from request arguments.
 
     Args:
-        args_dict (Dict[str, str]): Dictionary of request arguments.
+        args_dict (dict[str, str]): Query string arguments from the request.
 
     Returns:
-        Tuple[int, int]: Tuple of page and limit.
-    """
+        tuple[int, int]: The requested page number and page size.
+    Raises:
+        CustomHTTPException: If the requested ``limit`` exceeds the configured
+        maximum.
 
-    # Pagination defaults and maximums
+    Notes:
+        Defaults are used when ``page`` or ``limit`` are missing.
+    """
 
     PAGINATION_DEFAULTS, PAGINATION_MAX = create_pagination_defaults()
 
-    # Parse page and limit values
     page = int(args_dict.get("page", PAGINATION_DEFAULTS["page"]))
     limit = int(args_dict.get("limit", PAGINATION_DEFAULTS["limit"]))
 
@@ -129,15 +144,21 @@ def get_group_by_fields(
     all_columns: dict[str, dict[str, hybrid_property | InstrumentedAttribute]],
     base_model: DeclarativeBase,
 ) -> list[Callable]:
-    """Retrieve ``GROUP BY`` columns from request arguments.
+    """Derive ``GROUP BY`` SQLAlchemy columns from query parameters.
 
     Args:
-        args_dict: Dictionary of request arguments.
-        all_columns: Nested dictionary of table names and their columns.
-        base_model: The base SQLAlchemy model.
+
+        args_dict (dict[str, str]): Query string arguments containing an
+            optional ``groupby`` entry.
+        all_columns (dict[str, dict[str, hybrid_property | InstrumentedAttribute]]):
+            Mapping of table names to their accessible columns/hybrid
+            properties.
+        base_model (DeclarativeBase): Base model used for resolving table
+            names when not explicitly provided.
 
     Returns:
-        List of columns to apply in the ``GROUP BY`` clause.
+        list[Callable]: Columns to use in the ``GROUP BY`` clause. Returns an
+        empty list when ``groupby`` is absent.
     """
 
     group_by_fields: list[Callable] = []
@@ -152,14 +173,19 @@ def get_group_by_fields(
 
 
 def get_models_for_join(args_dict: dict[str, str], get_model_func: Callable[[str], DeclarativeBase]) -> dict[str, DeclarativeBase]:
-    """Build a mapping of models to join based on the ``join`` query parameter.
+    """Build a mapping of models to join from the ``join`` query parameter.
 
     Args:
-        args_dict: Dictionary of request arguments.
-        get_model_func: Function used to resolve a model by name.
+        args_dict: Mapping of request arguments.
+        get_model_func: Callback used to resolve a model name to a class.
 
     Returns:
-        Dictionary mapping requested join names to SQLAlchemy model classes.
+        dict[str, DeclarativeBase]: Requested join names mapped to model classes.
+        An empty dictionary is returned when no joins are requested.
+
+    Raises:
+        CustomHTTPException: If a requested join model cannot be resolved.
+
     """
 
     models: dict[str, DeclarativeBase] = {}
@@ -175,15 +201,19 @@ def get_models_for_join(args_dict: dict[str, str], get_model_func: Callable[[str
 
 
 def get_table_column(key: str, all_columns: dict[str, dict[str, Any]]) -> tuple[str, str, str]:
-    """
-    Get the fully qualified column name (i.e., with table name).
+    """Resolve a request key to its table name, column, and operator.
 
     Args:
-        key (str): The column name.
-        all_columns (Dict[str, Dict[str, Any]]): Nested dictionary of table names and their columns.
+        key: Request argument key containing a column name and optional operator
+            (e.g., ``"id__eq"`` or ``"users.id__eq"``).
+        all_columns: Mapping of table names to their column attributes.
 
     Returns:
-        Tuple[str, str, str]: A tuple containing the table name, column name, and operator.
+        tuple[str, str, str]: The table name, column name, and operator. The
+        operator is an empty string if none is specified.
+
+    Raises:
+        CustomHTTPException: If ``key`` does not correspond to a known column.
     """
     keys_split = key.split("__")
     column_name = keys_split[0]
@@ -204,16 +234,19 @@ def get_select_fields(
     base_model: DeclarativeBase,
     all_columns: dict[str, dict[str, Column]],
 ) -> list[Callable]:
-    """
-    Get the select fields from the request arguments.
+    """Determine explicit column selection from query parameters.
 
     Args:
-        args_dict (Dict[str, str]): Dictionary of request arguments.
-        base_model (DeclarativeBase): The base SQLAlchemy model.
-        all_columns (Dict[str, Dict[str, Column]]): Nested dictionary of table names and their columns.
+        args_dict (dict[str, str]): Query string arguments which may contain a
+            comma-separated ``fields`` entry.
+        base_model (DeclarativeBase): Base model used to infer table names when
+            ``fields`` entries omit them.
+        all_columns (dict[str, dict[str, Column]]): Mapping of table names to
+            their available SQLAlchemy columns.
 
     Returns:
-        List[Callable]: List of conditions to apply in the query.
+        list[Callable]: SQLAlchemy columns to include in the ``SELECT`` clause.
+        Returns an empty list when ``fields`` is absent.
     """
     select_fields = []
     if "fields" in args_dict:
@@ -404,10 +437,14 @@ def validate_table_and_column(table_name: str, column_name: str, all_columns: di
     """
     from flarchitect.utils.general import get_config_or_model_meta
 
-    field_case = get_config_or_model_meta("API_FIELD_CASE", default="snake_case")
+    # Ensure default matches supported values in convert_case
+    field_case = get_config_or_model_meta("API_FIELD_CASE", default="snake")
     column_name = convert_case(column_name, field_case)
 
     all_models_columns = all_columns.get(table_name)
+    if not all_models_columns:
+        # Fallback to case-insensitive lookup to avoid issues with mixed casing
+        all_models_columns = all_columns.get(table_name.lower())
     if not all_models_columns:
         raise CustomHTTPException(400, f"Invalid table name: {table_name}")
 
