@@ -45,13 +45,15 @@ from flarchitect.utils.core_utils import convert_case
 
 
 class EnumField(fields.Field):
-    """Custom field to handle Enum serialization and deserialization by their keys."""
+    """Custom field to handle Enum serialisation and deserialisation by key."""
 
     def __init__(self, enum, by_value=False, **kwargs):
-        """
-        :param enum: The Enum class to use.
-        :param by_value: If True, serialize/deserialize using Enum values instead of keys.
-        :param kwargs: Additional keyword arguments.
+        """Initialise the field.
+
+        Args:
+            enum: The Enum class to use.
+            by_value: If True, serialise/deserialise using Enum values instead of keys.
+            **kwargs: Additional keyword arguments.
         """
         self.enum = enum
         self.by_value = by_value
@@ -133,7 +135,12 @@ class AutoSchema(Base):
         include_children = True
 
     def __init__(self, *args, render_nested=True, **kwargs):
-        """Initialize the AutoSchema instance."""
+        """Initialise the ``AutoSchema`` instance.
+
+        Why/How:
+            Configures field generation against the bound model, sets case
+            conversion preferences and prepares context for nested rendering.
+        """
         self.render_nested = render_nested
         self.depth = kwargs.pop("depth", 0)
         only_fields = kwargs.pop("only", None)
@@ -190,11 +197,13 @@ class AutoSchema(Base):
         mapper = class_mapper(self.model)
         for attribute, mapper_property in mapper.all_orm_descriptors.items():
             original_attribute = attribute
-            attribute = self._convert_case(attribute)
-
-            if self._should_skip_attribute(attribute):
+            # Determine if we should skip based on the original attribute
+            if self._should_skip_attribute(original_attribute):
                 continue
 
+            # Convert case, preserving leading underscore when configured to show them
+            attribute = self._convert_case(original_attribute)
+
             # Access the actual property from the InstrumentedAttribute
             prop = getattr(mapper_property, "property", None)
 
@@ -213,12 +222,25 @@ class AutoSchema(Base):
         # print("Load fields:", self.load_fields)  # Should match self.fields
 
     def _convert_case(self, attribute: str) -> str:
-        """Convert the attribute name to the appropriate case."""
-        field_case = get_config_or_model_meta("API_FIELD_CASE", model=self.model, default="snake_case")
-        return convert_case(attribute, field_case)
+        """Convert the attribute name to the appropriate case.
+
+        Preserves a leading underscore when ``API_IGNORE_UNDERSCORE_ATTRIBUTES``
+        is ``False`` so that hidden fields remain visibly prefixed in outputs.
+        """
+        field_case = get_config_or_model_meta("API_FIELD_CASE", model=self.model, default="snake")
+        has_leading_underscore = attribute.startswith("_")
+        # Convert without the leading underscore to get correct casing
+        base = attribute.lstrip("_") if has_leading_underscore else attribute
+        converted = convert_case(base, field_case)
+        if has_leading_underscore and not get_config_or_model_meta("API_IGNORE_UNDERSCORE_ATTRIBUTES", model=self.model, default=True):
+            return f"_{converted}"
+        return converted
 
     def _should_skip_attribute(self, attribute: str) -> bool:
-        """Determine if the attribute should be skipped."""
+        """Determine if the attribute should be skipped.
+
+        Uses the original attribute name to detect a leading underscore.
+        """
         return attribute.startswith("_") and get_config_or_model_meta("API_IGNORE_UNDERSCORE_ATTRIBUTES", model=self.model, default=True)
 
     def _handle_relationship(
@@ -235,7 +257,7 @@ class AutoSchema(Base):
                 return
         except RuntimeError:
             # this happens when the model is outside the flask request and is expected when the schema is first
-            # initialized
+            # initialised
             pass
 
         self.add_relationship_field(attribute, original_attribute, mapper_property)
@@ -272,8 +294,24 @@ class AutoSchema(Base):
 
         self._update_field_metadata(original_attribute)
 
-    def add_column_field(self, attribute: str, original_attribute: str, column_type: Any):
-        """Automatically add a field for a given column in the SQLAlchemy model."""
+    def add_column_field(self, attribute: str, original_attribute: str, column_type: Any) -> None:
+        """Add a schema field for a SQLAlchemy column.
+
+        Args:
+            attribute (str): Name of the field exposed by the schema.
+            original_attribute (str): Name of the attribute on the SQLAlchemy model.
+            column_type (Any): SQLAlchemy column type instance being converted.
+
+        Returns:
+            None: The field is added directly to ``self.fields`` and related mappings.
+
+        Assumptions:
+            ``column_type`` is either an ``Enum`` or present in ``type_mapping``.
+
+        Side Effects:
+            Mutates ``self`` by inserting the generated field and updating its
+            metadata via :meth:`_update_field_metadata`.
+        """
 
         # Check if the attribute should be skipped
         if self._should_skip_attribute(attribute):
@@ -307,16 +345,21 @@ class AutoSchema(Base):
         # Update the OpenAPI metadata for the field
         self._update_field_metadata(original_attribute)
 
-    def add_to_fields(self, attribute, field, load=True, dump=True):
-        """
-        Add a field to the fields dictionary
+    def add_to_fields(self, attribute: str, field: fields.Field, load: bool = True, dump: bool = True) -> None:
+        """Register a field on the schema.
+
         Args:
-            attribute (str): The attribute name
-            field (Field): The field object
+            attribute (str): Attribute name on the schema.
+            field (fields.Field): Marshmallow field to register.
+            load (bool, optional): Whether the field should be available for loading.
+            dump (bool, optional): Whether the field should be available for dumping.
 
         Returns:
             None
 
+        Side Effects:
+            Updates ``declared_fields``, ``fields``, ``load_fields`` and
+            ``dump_fields`` dictionaries on the schema.
         """
         self.declared_fields[attribute] = field
 
@@ -326,8 +369,19 @@ class AutoSchema(Base):
         if dump:
             self.dump_fields[attribute] = field
 
-    def _get_column_field_attrs(self, original_attribute: str, column_type: Any) -> dict:
-        """Get additional arguments for column fields."""
+    def _get_column_field_attrs(self, original_attribute: str, column_type: Any) -> dict[str, Any]:
+        """Compute Marshmallow field arguments for a model column.
+
+        Args:
+            original_attribute (str): Name of the column on the SQLAlchemy model.
+            column_type (Any): SQLAlchemy column type instance.
+
+        Returns:
+            dict[str, Any]: Keyword arguments to apply when instantiating the field.
+
+        Assumptions:
+            ``self.model`` exposes ``__table__`` and ``original_attribute`` exists on it.
+        """
         column = self.model.__table__.columns.get(original_attribute)
 
         # Check if column is None
@@ -439,15 +493,21 @@ class AutoSchema(Base):
 
         return field_args
 
-    def get_url(self, obj, attribute, other_schema):
-        """
-        Get the URL for a related object.
+    def get_url(self, obj: Any, attribute: str, other_schema: Schema) -> str | list[str] | None:
+        """Resolve a URL for a related object.
+
         Args:
-            obj (Any): The object to get the URL from.
-            attribute (str): The attribute name to get the URL for.
+            obj (Any): Parent object from which to read the relationship.
+            attribute (str): Relationship attribute name on ``obj``.
+            other_schema (Schema): Related schema class; currently unused but
+                reserved for future customization.
 
         Returns:
+            str | list[str] | None: URL or list of URLs returned from the related
+            object's ``to_url`` method, or ``None`` if the relationship is empty.
 
+        Assumptions:
+            Related objects implement a ``to_url`` method.
         """
         related = getattr(obj, attribute)
         if isinstance(related, list):
@@ -457,15 +517,21 @@ class AutoSchema(Base):
         else:
             return None
 
-    def get_many_url(self, obj, attribute, other_schema):
-        """
-        Get the URL for many related object.
+    def get_many_url(self, obj: Any, attribute: str, other_schema: Schema) -> str | list[str]:
+        """Resolve URLs for collection relationships.
+
         Args:
-            obj (Any): The object to get the URL from.
-            attribute (str): The attribute name to get the URL for.
+            obj (Any): Parent object from which to read the relationship.
+            attribute (str): Relationship attribute name on ``obj``.
+            other_schema (Schema): Schema class describing the related model.
 
         Returns:
+            str | list[str]: Result of calling the generated ``*_to_url`` method
+            on ``obj`` for the related model.
 
+        Assumptions:
+            ``obj`` exposes a ``<child>_to_url`` method for the related model as
+            determined by the configured endpoint namer.
         """
 
         child_end = get_config_or_model_meta("API_ENDPOINT_NAMER", other_schema.Meta.model, default=endpoint_namer)(other_schema.Meta.model)
@@ -477,8 +543,22 @@ class AutoSchema(Base):
         attribute: str,
         original_attribute: str,
         relationship_property: RelationshipProperty,
-    ):
-        """Automatically add a field for a given relationship in the SQLAlchemy model."""
+    ) -> None:
+        """Add a schema field for a SQLAlchemy relationship.
+
+        Args:
+            attribute (str): Name of the field exposed by the schema.
+            original_attribute (str): Name of the relationship attribute on the model.
+            relationship_property (RelationshipProperty): SQLAlchemy relationship
+                descriptor.
+
+        Returns:
+            None
+
+        Side Effects:
+            Modifies schema field mappings and updates field metadata. May add
+            additional load-only fields when nested writes are enabled.
+        """
         allow_nested_writes = get_config_or_model_meta("ALLOW_NESTED_WRITES", model=self.model, default=False)
         max_depth = 2 if allow_nested_writes else 1
         current_depth = self.context.get("current_depth", 0)
@@ -635,15 +715,34 @@ class AutoSchema(Base):
             load_field = fields.List(fields.Nested(input_schema), load_only=True) if relationship_prop.uselist else fields.Nested(input_schema, load_only=True)
             self.add_to_fields(field_name, load_field, dump=False)
 
-    def _update_field_metadata(self, attribute: str):
-        """Update metadata for the generated field."""
+    def _update_field_metadata(self, attribute: str) -> None:
+        """Populate OpenAPI metadata for a field.
+
+        Args:
+            attribute (str): Field name whose metadata should be updated.
+
+        Returns:
+            None
+
+        Side Effects:
+            Mutates the field's ``metadata`` dictionary in-place.
+        """
         field_obj = self.fields[attribute]  # Get the Marshmallow field object
         field_meta = field_obj.metadata  # Extract the existing metadata
 
-        # Correctly call get_openapi_meta_data with the field object
-        openapi_meta_data = get_openapi_meta_data(field_obj)
+        # Populate metadata from SQLAlchemy column ``info`` if available.
+        model_field = getattr(self.model, attribute, None)
+        if model_field is not None and hasattr(model_field, "info"):
+            info = model_field.info
+            if desc := info.get("description"):
+                field_meta.setdefault("description", desc)
+            if example := info.get("example"):
+                field_meta.setdefault("example", example)
+            if fmt := info.get("format"):
+                field_meta.setdefault("format", fmt)
 
-        # If the function returns metadata, update the field's metadata
+        # Merge additional OpenAPI-specific metadata derived from the field
+        openapi_meta_data = get_openapi_meta_data(field_obj)
         if openapi_meta_data:
             field_meta.update(openapi_meta_data)
 
