@@ -1,3 +1,4 @@
+import base64
 import re
 from collections.abc import Callable, Iterable
 from datetime import date, datetime, time
@@ -215,12 +216,85 @@ def wrap_validator(validator: Callable[[str], bool | VE], error_message: str = "
             if isinstance(out, VE):
                 raise ValidationError(error_message)
         except ValidationError as err:
-            # Re-raise the error to match Marshmallow's default behavior
+            # Re-raise the error to match Marshmallow's default behaviour
             raise ValidationError(err.messages) from err
 
     return wrapper
 
 
+def validate_base64(value: str) -> bool:
+    """Validate that a string is valid Base64.
+
+    Uses Python's ``base64`` module with strict validation.
+
+    Raises ``ValidationError`` if decoding fails.
+    """
+    try:
+        # validate=True ensures only valid base64 alphabet and correct padding
+        base64.b64decode(value, validate=True)
+        return True
+    except Exception as err:  # ValueError, binascii.Error
+        raise ValidationError("Base64 string is not valid.") from err
+
+
+def validate_cron(value: str) -> bool:
+    """Validate a simple 5-field cron expression.
+
+    Accepts common forms like ``*``, numbers, ranges (``1-5``), steps (``*/5`` or ``1-10/2``), and lists (``1,2,3``).
+    """
+    parts = value.split()
+    if len(parts) != 5:
+        raise ValidationError("Cron expression is not valid.")
+
+    field_re = re.compile(r"^(\*|\d+|\d+-\d+|\*/\d+|\d+-\d+/\d+|\d+(,\d+)*)$")
+    for part in parts:
+        if not field_re.fullmatch(part):
+            raise ValidationError("Cron expression is not valid.")
+    return True
+
+
+_ISO_4217_CODES: set[str] = {
+    # Common currencies (not exhaustive, just enough for tests and typical usage)
+    "USD",
+    "EUR",
+    "GBP",
+    "JPY",
+    "AUD",
+    "CAD",
+    "CHF",
+    "CNY",
+    "SEK",
+    "NZD",
+    "MXN",
+    "SGD",
+    "HKD",
+    "NOK",
+    "KRW",
+    "TRY",
+    "RUB",
+    "INR",
+    "BRL",
+    "ZAR",
+}
+
+
+def validate_currency(value: str) -> bool:
+    """Validate a 3-letter ISO 4217 currency code.
+
+    The set is intentionally curated (non-exhaustive) and excludes placeholders like ``XXX``.
+    """
+    if isinstance(value, str) and len(value) == 3 and value.isalpha() and value.isupper() and value in _ISO_4217_CODES:
+        return True
+    raise ValidationError("Currency code is not valid.")
+
+
+def _validate_hex_hash(value: str, length: int, algo_name: str) -> bool:
+    """Validate a hex-encoded hash string of a given length."""
+    if isinstance(value, str) and re.fullmatch(rf"[0-9a-fA-F]{{{length}}}", value):
+        return True
+    raise ValidationError(f"{algo_name} hash is not valid.")
+
+
 def validate_by_type(validator_type: str) -> Callable[[str], None] | None:
     """Return a validation function based on the type of validator.
 
@@ -239,20 +313,20 @@ def validate_by_type(validator_type: str) -> Callable[[str], None] | None:
         "mac": wrap_validator(validators.mac_address, "MAC address is not valid."),
         "hostname": wrap_validator(validators.hostname, "Hostname is not valid."),
         "iban": wrap_validator(validators.iban, "IBAN is not valid."),
-        "cron": wrap_validator(validators.cron, "Cron expression is not valid."),
-        "base64": wrap_validator(validators.base64, "Base64 string is not valid."),
+        "cron": validate_cron,
+        "base64": validate_base64,
         "slug": wrap_validator(validators.slug, "Slug is not valid."),
         "uuid": wrap_validator(validators.uuid, "UUID is not valid."),
         "card": wrap_validator(validators.card_number, "Card number is not valid."),
         "country_code": wrap_validator(validators.country_code, "Country code is not valid."),
         "domain": wrap_validator(validators.domain, "Domain is not valid."),
-        "md5": wrap_validator(validators.md5, "MD5 hash is not valid."),
-        "sha1": wrap_validator(validators.sha1, "SHA1 hash is not valid."),
-        "sha224": wrap_validator(validators.sha224, "SHA224 hash is not valid."),
-        "sha256": wrap_validator(validators.sha256, "SHA256 hash is not valid."),
-        "sha384": wrap_validator(validators.sha384, "SHA384 hash is not valid."),
-        "sha512": wrap_validator(validators.sha512, "SHA512 hash is not valid."),
-        "currency": wrap_validator(validators.currency, "Currency code is not valid."),
+        "md5": lambda v: _validate_hex_hash(v, 32, "MD5"),
+        "sha1": lambda v: _validate_hex_hash(v, 40, "SHA1"),
+        "sha224": lambda v: _validate_hex_hash(v, 56, "SHA224"),
+        "sha256": lambda v: _validate_hex_hash(v, 64, "SHA256"),
+        "sha384": lambda v: _validate_hex_hash(v, 96, "SHA384"),
+        "sha512": lambda v: _validate_hex_hash(v, 128, "SHA512"),
+        "currency": validate_currency,
         "phone": validate_phone_number,
         "postal_code": validate_postal_code,
         "date": lambda value: validate_date(value, formats=["%Y-%m-%d", "%d-%m-%Y", "%m/%d/%Y"]),
