@@ -6,7 +6,9 @@ from typing import TYPE_CHECKING, Any
 
 from apispec import APISpec
 from apispec.ext.marshmallow import MarshmallowPlugin
-from flask import Blueprint, Flask, current_app
+from apispec.ext.marshmallow.common import make_schema_key, resolve_schema_instance
+from flask import Blueprint, Flask, Response, current_app, redirect, request, session
+from flask_login import current_user, login_user
 from marshmallow import Schema
 from sqlalchemy.orm import DeclarativeBase
 
@@ -15,31 +17,32 @@ from flarchitect.core.routes import (
     create_query_params_from_rule,
     find_rule_by_function,
 )
+from flarchitect.logging import logger
 from flarchitect.specs.utils import (
-    _prepare_patch_schema,
     append_parameters,
     convert_path_to_openapi,
-    handle_authorization,
-    initialize_spec_template,
+    handle_authorisation,
+    initialise_spec_template,
+    schema_name_resolver,
     scrape_extra_info_from_spec_data,
 )
 from flarchitect.utils.config_helpers import get_config_or_model_meta
-from flarchitect.utils.core_utils import convert_case
 from flarchitect.utils.general import (
-    AttributeInitializerMixin,
-    find_child_from_parent_dir,
+    AttributeInitialiserMixin,
     generate_readme_html,
+    get_html_path,
     make_base_dict,
     manual_render_absolute_template,
     pretty_print_dict,
     search_all_keys,
 )
+from flarchitect.utils.response_helpers import create_response
 
 if TYPE_CHECKING:  # pragma: no cover - imported only for type hints
     from flarchitect import Architect
 
 
-class CustomSpec(APISpec, AttributeInitializerMixin):
+class CustomSpec(APISpec, AttributeInitialiserMixin):
     """A subclass of APISpec for specifying tag groups with extended features."""
 
     app: Flask
@@ -53,11 +56,11 @@ class CustomSpec(APISpec, AttributeInitializerMixin):
     api_logo_background: str | None = None
     api_keywords: list[str] | None = None
     create_docs: bool | None = True
-    documentation_url_prefix: str | None = "/"
+    documentation_url_prefix: str | None = None
     documentation_url: str | None = "/docs"
 
     def __init__(self, app: Flask, architect: Architect, *args, **kwargs):
-        """Initializes the CustomSpec object.
+        """Initialises the CustomSpec object.
 
         Args:
             app (Flask): The Flask application.
@@ -67,11 +70,18 @@ class CustomSpec(APISpec, AttributeInitializerMixin):
         """
         self.app = app
         self.architect = architect
-        # initialize per-instance containers to avoid shared mutable defaults
+        # initialise per-instance containers to avoid shared mutable defaults
         self.spec_groups: dict[str, list[dict[str, str | list[str]]]] = {"x-tagGroups": []}
         self.api_keywords: list[str] = []
         super().__init__(*args, **self._prepare_api_spec_data(**kwargs))
 
+        # Reset MarshmallowPlugin schema refs to avoid cross-app/test bleed.
+        import contextlib
+        with contextlib.suppress(Exception):
+            plugin = next((p for p in self.plugins if isinstance(p, MarshmallowPlugin)), None)
+            if plugin and getattr(getattr(plugin, "converter", None), "refs", None) is not None:
+                plugin.converter.refs.clear()  # type: ignore[attr-defined]
+
         if self._should_create_docs():
             self.architect.api_spec = self
             self._create_specification_blueprint()
@@ -83,21 +93,29 @@ class CustomSpec(APISpec, AttributeInitializerMixin):
         Returns:
             dict: The API specification as a dictionary.
         """
+        # Notify plugins that spec build is starting/completing
+        import contextlib
+        with contextlib.suppress(Exception):
+            self.architect.plugins.spec_build_started(self)
         spec_dict = super().to_dict()
+        with contextlib.suppress(Exception):
+            maybe = self.architect.plugins.spec_build_completed(spec_dict)
+            if isinstance(maybe, dict):
+                spec_dict = maybe
         if self.spec_groups:
             spec_dict.update(self.spec_groups)
         return spec_dict
 
     def _prepare_api_spec_data(self, **kwargs) -> dict:
-        """Prepares the data required to initialize the API spec.
+        """Prepares the data required to initialise the API spec.
 
         Returns:
-            dict: Data for initializing the API spec.
+            dict: Data for initialising the API spec.
         """
         api_description = self._get_api_description()
         api_spec_data = {
             "openapi_version": "3.0.2",
-            "plugins": [MarshmallowPlugin()],
+            "plugins": [MarshmallowPlugin(schema_name_resolver=schema_name_resolver)],
             "title": self._get_config("API_TITLE", "My API"),
             "version": self._get_config("API_VERSION", "1.0.0"),
             "info": {
@@ -106,6 +124,15 @@ class CustomSpec(APISpec, AttributeInitializerMixin):
                 **self._get_license_info(),
                 **self._get_logo_info(),
             },
+            "components": {
+                "securitySchemes": {
+                    "bearerAuth": {
+                        "type": "http",
+                        "scheme": "bearer",
+                        "bearerFormat": "JWT",
+                    }
+                }
+            },
             **self._get_servers_info(),
         }
         return {**api_spec_data, **kwargs}
@@ -196,7 +223,7 @@ class CustomSpec(APISpec, AttributeInitializerMixin):
         return get_config_or_model_meta("API_CREATE_DOCS", default=True)
 
     def validate_init_apispec_args(self) -> None:
-        """Validates the initialization arguments for the API spec.
+        """Validates the initialisation arguments for the API spec.
 
         Raises:
             ValueError: If any required argument is invalid.
@@ -229,8 +256,14 @@ class CustomSpec(APISpec, AttributeInitializerMixin):
         tag_groups.append({"name": group_name, "tags": [tag_name]})
 
     def _create_specification_blueprint(self) -> None:
-        """Sets up the blueprint to serve the API specification and documentation."""
-        html_path = find_child_from_parent_dir("src", "html", current_dir=os.path.dirname(os.path.abspath(__file__)))
+        """Sets up the blueprint to serve the API specification and documentation.
+
+        The HTML template directory is resolved dynamically using
+        :func:`~flarchitect.utils.general.get_html_path` to avoid reliance on
+        global state.
+        """
+
+        html_path = get_html_path()
 
         specification = Blueprint(
             "specification",
@@ -240,27 +273,100 @@ class CustomSpec(APISpec, AttributeInitializerMixin):
         )
 
         documentation_url = get_config_or_model_meta("API_DOCUMENTATION_URL", default="/docs")
+        docs_password = get_config_or_model_meta("API_DOCUMENTATION_PASSWORD", default=None)
+        docs_require_auth = get_config_or_model_meta("API_DOCUMENTATION_REQUIRE_AUTH", default=False)
+        auth_method = get_config_or_model_meta("API_AUTHENTICATE_METHOD", default=None)
+        user_model = get_config_or_model_meta("API_USER_MODEL", default=None)
 
-        @specification.route("swagger.json")
-        def get_swagger_spec() -> dict:
-            """Serves the Swagger spec as JSON.
+        def _ensure_docs_access(
+            json_only: bool = False,
+        ) -> Response | tuple[str, int] | None:
+            """Validate optional documentation authentication.
+
+            Args:
+                json_only (bool): When ``True`` return a JSON error response instead of HTML.
 
             Returns:
-                dict: The Swagger spec.
+                Optional[Union[Response, tuple[str, int]]]: ``None`` if access is granted, otherwise a response prompting for login.
             """
+
+            if not (docs_password or docs_require_auth):
+                return None
+
+            if session.get("docs_authenticated") or getattr(current_user, "is_authenticated", False):
+                return None
+
+            if request.method == "POST" and not json_only:
+                username = request.form.get("username")
+                password = request.form.get("password", "")
+
+                if docs_password and password == docs_password:
+                    session["docs_authenticated"] = True
+                    return redirect(request.path)
+
+                if auth_method and user_model and username and password:
+                    lookup_field = get_config_or_model_meta("API_USER_LOOKUP_FIELD", model=user_model, default=None)
+                    check_method = get_config_or_model_meta("API_CREDENTIAL_CHECK_METHOD", model=user_model, default=None)
+                    usr = user_model.query.filter(getattr(user_model, lookup_field) == username).first()
+                    if usr and getattr(usr, check_method)(password):
+                        session["docs_authenticated"] = True
+                        login_user(usr)
+                        return redirect(request.path)
+
+                error = "Invalid credentials"
+            else:
+                error = None
+
+            if json_only:
+                return create_response(status=401, errors="Unauthorized")
+
+            docs_style = get_config_or_model_meta("API_DOCS_STYLE", default="redoc").lower()
+            allow_username = bool(auth_method and user_model)
+            html = manual_render_absolute_template(
+                os.path.join(self.architect.get_templates_path(), "docs_login.html"),
+                config=self.app.config,
+                docs_style=docs_style,
+                allow_username=allow_username,
+                error=error,
+            )
+            return html, 200
+
+        @specification.route("apispec.json")
+        def get_swagger_spec() -> dict | Response | tuple[str, int]:
+            """Serve the Swagger spec as JSON.
+
+            Returns:
+                Union[dict, Response, tuple[str, int]]: The Swagger spec or an authentication response.
+            """
+
+            unauthorized = _ensure_docs_access(json_only=True)
+            if unauthorized:
+                return unauthorized
             return self.architect.to_api_spec()
 
-        @specification.route(documentation_url)
-        @specification.route(documentation_url + "/")
-        def get_docs() -> str:
-            """Serves the API documentation page.
+        @specification.route("swagger.json")
+        def get_legacy_swagger_spec() -> dict | Response | tuple[str, int]:
+            """Serve the Swagger spec at legacy ``swagger.json`` endpoint."""
+
+            return get_swagger_spec()
+
+        get_swagger_spec._auth_disabled = True
+
+        @specification.route(documentation_url, methods=["GET", "POST"])
+        @specification.route(documentation_url + "/", methods=["GET", "POST"])
+        def get_docs() -> str | Response | tuple[str, int]:
+            """Serve the API documentation page.
 
             Returns:
-                str: The HTML documentation page.
+                Union[str, Response, tuple[str, int]]: HTML documentation or an authentication response.
             """
+
+            unauthorized = _ensure_docs_access()
+            if unauthorized:
+                return unauthorized
+
             custom_headers = get_config_or_model_meta("API_DOCUMENTATION_HEADERS", default="") or self._get_config("API_DOC_HTML_HEADERS", "")
             docs_style = get_config_or_model_meta("API_DOCS_STYLE", default="redoc").lower()
- 
 
             template_name = "swagger.html" if docs_style == "swagger" else "apispec.html"
             return manual_render_absolute_template(
@@ -269,8 +375,18 @@ class CustomSpec(APISpec, AttributeInitializerMixin):
                 custom_headers=custom_headers,
             )
 
+        get_docs._auth_disabled = True
+
         self.architect.app.register_blueprint(specification)
 
+        prefix = self.documentation_url_prefix or self._get_config("DOCUMENTATION_URL_PREFIX", "/")
+        docs_url = documentation_url if documentation_url.startswith("/") else f"/{documentation_url}"
+        full_url = f"{prefix.rstrip('/')}{docs_url}"
+        server_name = self.app.config.get("SERVER_NAME")
+        if server_name:
+            full_url = f"http://{server_name}{full_url}"
+        logger.log(1, f"API documentation available at |{full_url}|")
+
 
 def generate_swagger_spec(
     http_method: str,
@@ -309,7 +425,7 @@ def generate_swagger_spec(
         output_schema=output_schema,
         default=False,
     )
-    spec_template = initialize_spec_template(http_method, many, rate_limit, error_responses)
+    spec_template = initialise_spec_template(http_method, many, rate_limit, error_responses)
 
     append_parameters(
         spec_template,
@@ -321,7 +437,7 @@ def generate_swagger_spec(
         model,
         many,
     )
-    handle_authorization(f, spec_template)
+    handle_authorisation(f, spec_template)
 
     return spec_template
 
@@ -344,34 +460,32 @@ def register_schemas(
         None
     """
 
-    put_input_schema = _prepare_patch_schema(input_schema)
-
     # ``MarshmallowPlugin`` keeps track of registered schemas. Inspect the
     # plugin to avoid adding the same schema class twice, which would trigger
     # warnings from ``apispec``.
     plugin = next((p for p in spec.plugins if isinstance(p, MarshmallowPlugin)), None)
-    registered_refs = getattr(plugin, "refs", set()) if plugin else set()
+    registered_refs = getattr(getattr(plugin, "converter", None), "refs", {}) if plugin else {}
 
-    for schema in [input_schema, output_schema, put_input_schema]:
+    for schema in [input_schema, output_schema]:
         if schema:
-            model = schema.get_model() if hasattr(schema, "get_model") else None
+            schema_instance = resolve_schema_instance(schema)
+            schema_name = schema_name_resolver(schema_instance)
 
-            schema_name = convert_case(
-                schema.__name__.replace("Schema", "") if hasattr(schema, "__name__") else schema.__class__.__name__.replace("Schema", ""),
-                get_config_or_model_meta("API_SCHEMA_CASE", model=model, default="camel"),
-            )
-            schema.__name__ = schema_name
-
-            schema_cls = schema if isinstance(schema, type) else schema.__class__
-            schema_key = f"{schema_cls.__module__}.{schema_cls.__name__}"
-            if schema_key in registered_refs and not force_update:
+            schema_key = make_schema_key(schema_instance)
+            existing_ref = registered_refs.get(schema_key)
+            if existing_ref and not force_update:
+                if existing_ref != schema_name:
+                    spec.components.schemas[schema_name] = spec.components.schemas.pop(existing_ref)
+                    registered_refs[schema_key] = schema_name
                 continue
 
             existing_schema = spec.components.schemas.get(schema_name)
             if existing_schema and force_update:
-                spec.components.schemas[schema_name] = schema
+                spec.components.schemas[schema_name] = schema_instance
             elif not existing_schema:
-                spec.components.schema(schema_name, schema=schema)
+                spec.components.schema(schema_name, schema=schema_instance)
+
+            registered_refs[schema_key] = schema_name
 
 
 def register_routes_with_spec(architect: Architect, route_spec: list[dict[str, Any]] | None = None) -> None:
@@ -397,7 +511,8 @@ def register_routes_with_spec(architect: Architect, route_spec: list[dict[str, A
             if rule:
                 methods = rule.methods - {"OPTIONS", "HEAD"}
                 for http_method in methods:
-                    route_info = scrape_extra_info_from_spec_data(route_info, method=http_method)
+                    summary = route_info.get("summary")
+                    route_info = scrape_extra_info_from_spec_data(route_info, method=http_method, summary=summary)
                     path = rule.rule
 
                     output_schema = route_info.get("output_schema")
@@ -426,6 +541,8 @@ def register_routes_with_spec(architect: Architect, route_spec: list[dict[str, A
                     )
 
                     endpoint_spec["tags"] = [tag]
+                    if not any(t.get("name") == tag for t in architect.api_spec._tags):
+                        architect.api_spec.tag({"name": tag})
 
                     if route_info.get("group_tag"):
                         architect.api_spec.set_xtags_group(tag, route_info["group_tag"])
@@ -439,7 +556,3 @@ def register_routes_with_spec(architect: Architect, route_spec: list[dict[str, A
                         path=convert_path_to_openapi(path),
                         operations={http_method.lower(): endpoint_spec},
                     )
-
-    from flarchitect.schemas.bases import AutoSchema
-
-    register_schemas(architect.api_spec, AutoSchema)
