@@ -1,25 +1,19 @@
 import copy
 import os
 import random
+import re
 from collections.abc import Callable
 from copy import deepcopy
-from datetime import datetime, timedelta
+from datetime import datetime, timedelta, timezone
 from typing import Any
 
-import pytz
-from flask import current_app
 from marshmallow import Schema, fields
 from marshmallow_sqlalchemy.fields import Nested, Related, RelatedList
 from sqlalchemy.orm import DeclarativeBase
 from werkzeug.http import HTTP_STATUS_CODES
 from werkzeug.routing import IntegerConverter, UnicodeConverter
 
-import flarchitect.utils
-import flarchitect.utils.decorators
-from flarchitect.database.inspections import (
-    get_model_columns,
-    get_model_relationships,
-)
+from flarchitect.database.inspections import get_model_columns, get_model_relationships
 from flarchitect.database.utils import AGGREGATE_FUNCS
 from flarchitect.logging import logger
 from flarchitect.utils.config_helpers import get_config_or_model_meta
@@ -27,10 +21,27 @@ from flarchitect.utils.core_utils import convert_case
 from flarchitect.utils.general import (
     DATE_FORMAT,
     DATETIME_FORMAT,
-    html_path,
+    get_html_path,
     manual_render_absolute_template,
     pluralize_last_word,
 )
+from flarchitect.utils.response_helpers import create_response
+
+
+def schema_name_resolver(schema: Schema) -> str:
+    """Resolve a schema name based on configuration.
+
+    Args:
+        schema (Schema): Schema instance or class whose name requires resolving.
+
+    Returns:
+        str: The schema name converted using ``API_SCHEMA_CASE``.
+    """
+
+    schema_cls = schema if isinstance(schema, type) else schema.__class__
+    model = getattr(getattr(schema_cls, "Meta", None), "model", None)
+    case = get_config_or_model_meta("API_SCHEMA_CASE", model=model, default="camel") or "camel"
+    return convert_case(schema_cls.__name__.replace("Schema", ""), case)
 
 
 def scrape_extra_info_from_spec_data(
@@ -57,7 +68,16 @@ def scrape_extra_info_from_spec_data(
     function = spec_data.get("function")
 
     if not all([model, output_schema or input_schema, method, function]):
-        logger.log(1, "Missing data for documentation generation")
+        missing = []
+        if not model:
+            missing.append("model")
+        if not (output_schema or input_schema):
+            missing.append("schema")
+        if not method:
+            missing.append("method")
+        if not function:
+            missing.append("function")
+        logger.log(1, f"Missing data for documentation generation: {', '.join(missing)}")
 
     if spec_data.get("tag") is None:
         new_tag = get_config_or_model_meta("tag", model, output_schema, input_schema, "Unknown")
@@ -123,39 +143,6 @@ def get_param_schema(converter) -> dict[str, str]:
         return {"type": "string"}
 
 
-# def generate_delete_query_params(schema: Schema, model: DeclarativeBase) -> List[Dict[str, Any]]:
-#     """Helper function to generate query parameters for DELETE method.
-#
-#     Args:
-#         schema (Schema): The schema associated with the model.
-#         model (DeclarativeBase): The SQLAlchemy model.
-#
-#     Returns:
-#         List[Dict[str, Any]]: List of query parameters for DELETE method.
-#     """
-#     query_params = []
-#     if get_config_or_model_meta("API_ALLOW_DELETE_RELATED", getattr(schema.Meta, "model", None), default=True):
-#         related = [x[1] for x in get_model_relationships(model)]
-#         query_params.append(
-#             {
-#                 "name": "delete_related",
-#                 "in": "query",
-#                 "schema": {"type": "string"},
-#                 "description": f"A comma-separated list of related resources to delete. Options include: {', '.join(related)}",
-#             }
-#         )
-#     if get_config_or_model_meta("API_ALLOW_DELETE_DEPENDENTS", getattr(schema.Meta, "model", None), default=True):
-#         query_params.append(
-#             {
-#                 "name": "delete_dependents",
-#                 "in": "query",
-#                 "schema": {"type": "boolean"},
-#                 "description": "If true, will delete all recursively dependent resources.",
-#             }
-#         )
-#     return query_params
-
-
 def generate_delete_query_params(schema: Schema, model: DeclarativeBase) -> list[dict[str, Any]]:
     """Helper function to generate query parameters for DELETE method.
 
@@ -248,26 +235,22 @@ def generate_additional_query_params(methods: set, schema: Schema, model: Declar
 
 def _add_request_body_to_spec_template(
     spec_template: dict[str, Any],
-    http_method: str,
+    _http_method: str,
     input_schema: Schema,
-    model: DeclarativeBase | None,
+    _model: DeclarativeBase | None,
 ):
     """Helper function to add a request body to the spec template.
 
     Args:
         spec_template (Dict[str, Any]): The OpenAPI specification template to enhance.
-        http_method (str): The HTTP method (GET, POST, PUT, DELETE, PATCH).
+        _http_method (str): The HTTP method (GET, POST, PUT, DELETE, PATCH).
         input_schema (Schema): The Marshmallow schema for request body validation.
-        model (Optional[DeclarativeBase]): The SQLAlchemy model for database interactions.
+        _model (Optional[DeclarativeBase]): The SQLAlchemy model for database interactions.
 
     Returns:
         None
     """
-    case = get_config_or_model_meta("API_SCHEMA_CASE", model=model, default="camel")
-    name = convert_case(
-        ("patch_" if http_method == "PATCH" else "") + input_schema.__name__.replace("Schema", ""),
-        case,
-    )
+    name = schema_name_resolver(input_schema)
 
     spec_template["requestBody"] = {
         "description": f"`{name}` payload.",
@@ -285,7 +268,7 @@ def _add_response_to_spec_template(spec_template: dict[str, Any], output_schema:
 
     Args:
         spec_template (Dict[str, Any]): The OpenAPI specification template to enhance.
-        output_schema (Schema): The Marshmallow schema for response data serialization.
+        output_schema (Schema): The Marshmallow schema for response data serialisation.
 
     Returns:
         None
@@ -306,54 +289,89 @@ def _add_response_to_spec_template(spec_template: dict[str, Any], output_schema:
     )
 
 
-def _initialize_base_responses(method: str, many: bool, error_responses: list[int]) -> dict[str, dict[str, Any]]:
-    """Helper function to initialize base responses.
+def build_error_response(status_code: int, links: dict[str, Any] | None = None) -> dict[str, Any]:
+    """Build a standardised error response for the OpenAPI specification.
+
+    Args:
+        status_code (int): HTTP status code representing the error.
+        links (Optional[Dict[str, Any]]): Optional OpenAPI links related to the error.
+
+    Returns:
+        Dict[str, Any]: Response block including example payload.
+    """
+    example = create_response(status=status_code, errors={"error": HTTP_STATUS_CODES.get(status_code)}).get_json()
+
+    response: dict[str, Any] = {
+        "description": HTTP_STATUS_CODES.get(status_code),
+        "content": {"application/json": {"example": example}},
+    }
+
+    if links:
+        response["links"] = links
+
+    return response
+
+
+def _initialize_base_responses(
+    method: str,
+    many: bool,
+    error_responses: list[int],
+    links: dict[int, dict[str, Any]] | None = None,
+) -> dict[str, dict[str, Any]]:
+    """Initialise base responses for a route.
 
     Args:
         method (str): The HTTP method.
         many (bool): Whether the endpoint returns multiple items.
         error_responses (List[int]): List of error response status codes.
+        links (Optional[Dict[int, Dict[str, Any]]]): Links for specific error responses.
 
     Returns:
         Dict[str, Dict[str, Any]]: Dictionary of base responses.
     """
+    links = links or {}
     responses = {"200": {"description": "Successful operation"}}
 
     if 500 in error_responses or not error_responses:
-        responses["500"] = {"description": HTTP_STATUS_CODES.get(500)}
+        responses["500"] = build_error_response(500, links.get(500))
 
     if method != "POST" and not many and (404 in error_responses or not error_responses):
-        responses["404"] = {"description": HTTP_STATUS_CODES.get(404)}
+        responses["404"] = build_error_response(404, links.get(404))
 
     if method == "DELETE" and not many and (409 in error_responses or not error_responses):
-        responses["409"] = {"description": HTTP_STATUS_CODES.get(409)}
+        responses["409"] = build_error_response(409, links.get(409))
 
     return responses
 
 
-def _initialize_auth_responses(error_responses: list[int]) -> dict[str, dict[str, Any]]:
-    """Helper function to initialize authentication responses.
+def _initialize_auth_responses(
+    error_responses: list[int],
+    links: dict[int, dict[str, Any]] | None = None,
+) -> dict[str, dict[str, Any]]:
+    """Initialise authentication error responses.
 
     Args:
         error_responses (List[int]): List of error response status codes.
+        links (Optional[Dict[int, Dict[str, Any]]]): Links for specific error responses.
 
     Returns:
         Dict[str, Dict[str, Any]]: Dictionary of authentication responses.
     """
     responses = {}
+    links = links or {}
     auth_on = get_config_or_model_meta("API_AUTHENTICATE", default=False)
 
     if auth_on and (403 in error_responses or not error_responses):
-        responses["403"] = {"description": HTTP_STATUS_CODES.get(403)}
+        responses["403"] = build_error_response(403, links.get(403))
 
     if auth_on and (401 in error_responses or not error_responses):
-        responses["401"] = {"description": HTTP_STATUS_CODES.get(401)}
+        responses["401"] = build_error_response(401, links.get(401))
 
     return responses
 
 
 def _initialize_rate_limit_responses(rate_limit: bool) -> dict[str, dict[str, Any]]:
-    """Helper function to initialize rate limit responses.
+    """Helper function to initialise rate limit responses.
 
     Args:
         rate_limit (bool): Whether the endpoint has a rate limit.
@@ -582,7 +600,7 @@ def _prepare_patch_schema(input_schema: Schema | None) -> Schema | None:
     if not input_schema:
         return None
 
-    # Initialize a dictionary to hold the new class's fields
+    # Initialise a dictionary to hold the new class's fields
     class_fields = {}
 
     # Iterate over all fields in the input schema
@@ -636,6 +654,11 @@ def make_endpoint_description(schema: Schema, http_method: str, **kwargs) -> str
 
     parent = kwargs.get("parent")
     parent_name = parent.__name__ if parent else ""
+    if parent_name:
+        parent_name = convert_case(
+            parent_name,
+            get_config_or_model_meta("API_SCHEMA_CASE", model=parent, default="camel"),
+        )
 
     if http_method == "GET":
         if parent and many:
@@ -681,7 +704,7 @@ def generate_fields_description(schema: Schema) -> str:
         ]
         example_fields = [get_table_name(i, resource_name, fields, example_table) for i in range(3)]
 
-        full_path = os.path.join(html_path, "redoc_templates/fields.html")
+        full_path = os.path.join(get_html_path(), "redoc_templates/fields.html")
         schema_name = endpoint_namer(schema.Meta.model)
         api_prefix = get_config_or_model_meta("API_PREFIX", default="/api")
 
@@ -707,7 +730,7 @@ def generate_x_description(template_data: dict, path: str = "") -> str:
         str: Filter examples.
     """
     if template_data:
-        full_path = os.path.join(html_path, path)
+        full_path = os.path.join(get_html_path(), path)
         return manual_render_absolute_template(full_path, **template_data)
     else:
         return "This endpoint does not have a database table (or is computed etc) and should not be filtered\n"
@@ -722,7 +745,7 @@ def generate_filter_examples(schema: Schema) -> str:
     Returns:
         str: Filter examples.
     """
-    now = datetime.now(pytz.utc)
+    now = datetime.now(timezone.utc)
     yesterday = now - timedelta(days=1)
     day_before_yesterday = yesterday - timedelta(days=1)
 
@@ -735,7 +758,7 @@ def generate_filter_examples(schema: Schema) -> str:
     example_one = "&".join(examples[:split_examples])
     example_two = "&".join(examples[-split_examples:])
 
-    full_path = os.path.join(html_path, "redoc_templates/filters.html")
+    full_path = os.path.join(get_html_path(), "redoc_templates/filters.html")
 
     return manual_render_absolute_template(full_path, examples=[example_one, example_two])
 
@@ -747,9 +770,11 @@ def convert_path_to_openapi(path: str) -> str:
         path (str): Flask path to convert.
 
     Returns:
-        str: OpenAPI path.
+        str: OpenAPI path with Flask converters removed.
     """
-    return path.replace("<", "{").replace(">", "}").replace("<int:", "")
+    pattern = re.compile(r"<(?:[^:<>]+:)?([^<>]+)>")
+    # Replace Flask path converters with OpenAPI-style parameters
+    return pattern.sub(r"{\1}", path)
 
 
 def initialize_spec_template(
@@ -757,14 +782,16 @@ def initialize_spec_template(
     many: bool = False,
     rate_limit: bool = False,
     error_responses: list[int] | None = None,
+    links: dict[int, dict[str, Any]] | None = None,
 ) -> dict[str, Any]:
-    """Initializes the spec template with optional rate limiting headers for successful and rate-limited responses.
+    """Initialises the spec template with optional rate limiting headers for successful and rate-limited responses.
 
     Args:
         method (str): The HTTP method.
         many (bool): Whether the endpoint returns multiple items.
         rate_limit (bool): Whether the endpoint has a rate limit.
         error_responses (Optional[List[int]]): List of error response status codes.
+        links (Optional[Dict[int, Dict[str, Any]]]): Links for specific error responses.
 
     Returns:
         Dict[str, Any]: Spec template.
@@ -772,13 +799,37 @@ def initialize_spec_template(
     if not error_responses:
         error_responses = []
 
-    responses = _initialize_base_responses(method, many, error_responses)
-    responses.update(_initialize_auth_responses(error_responses))
+    if links is None:
+        raw_links = get_config_or_model_meta("links", default={}, method=method)
+        links = {int(k): v for k, v in raw_links.items()} if raw_links else {}
+
+    responses = _initialize_base_responses(method, many, error_responses, links)
+    responses.update(_initialize_auth_responses(error_responses, links))
     responses.update(_initialize_rate_limit_responses(rate_limit))
 
     return {"responses": responses, "parameters": []}
 
 
+def initialise_spec_template(
+    method: str,
+    many: bool = False,
+    rate_limit: bool = False,
+    error_responses: list[int] | None = None,
+    links: dict[int, dict[str, Any]] | None = None,
+) -> dict[str, Any]:
+    """UK spelling wrapper for ``initialize_spec_template``.
+
+    Mirrors arguments and behaviour; provided for naming consistency.
+    """
+    return initialize_spec_template(
+        method,
+        many=many,
+        rate_limit=rate_limit,
+        error_responses=error_responses,
+        links=links,
+    )
+
+
 def append_parameters(
     spec_template: dict[str, Any],
     query_params: list[dict[str, Any]],
@@ -797,14 +848,13 @@ def append_parameters(
         path_params (List[Dict[str, Any]]): A list of dictionaries defining path parameters.
         http_method (str): The HTTP method (GET, POST, PUT, DELETE, PATCH).
         input_schema (Optional[Schema]): The Marshmallow schema for request body validation.
-        output_schema (Optional[Schema]): The Marshmallow schema for response data serialization.
+        output_schema (Optional[Schema]): The Marshmallow schema for response data serialisation.
         model (Optional[DeclarativeBase]): The SQLAlchemy model for database interactions.
         many (bool): Whether the endpoint returns multiple items.
 
     Returns:
         None
     """
-    flarchitect.utils.general.html_path = current_app.extensions["flarchitect"].get_templates_path()
 
     spec_template.setdefault("parameters", []).extend(path_params + query_params)
     rate_limit = get_config_or_model_meta(
@@ -962,26 +1012,32 @@ def handle_authorization(f: Callable, spec_template: dict[str, Any]):
     Returns:
         None
     """
-    required_roles = None
+    required_roles: tuple[str, ...] | None = None
+    roles_label: str | None = None
 
     if hasattr(f, "_decorators"):
         for decorator in f._decorators:
-            if decorator.__name__ == "roles_required":
+            if decorator.__name__ in {
+                "roles_required",
+                "roles_accepted",
+                "require_roles",
+            }:
                 required_roles = decorator._args
-                spec_template["parameters"].append(
-                    {
-                        "name": "Authorization",
-                        "in": "header",
-                        "description": "JWT token required",
-                        "required": True,
-                        "schema": {"type": "string", "format": "jwt"},
-                    }
-                )
+                any_of = getattr(decorator, "_any_of", decorator.__name__ == "roles_accepted")
+                roles_label = "Roles accepted" if any_of else "Roles required"
+                security = spec_template.setdefault("security", [])
+                if not any("bearerAuth" in scheme for scheme in security):
+                    security.append({"bearerAuth": []})
                 break
 
-    if required_roles:
+    if required_roles and roles_label:
         roles_desc = ", ".join(required_roles)
-        spec_template["responses"]["401"]["description"] += f" Roles required: {roles_desc}."
+        spec_template["responses"]["401"]["description"] += f" {roles_label}: {roles_desc}."
+
+
+def handle_authorisation(f: Callable, spec_template: dict[str, Any]):
+    """UK spelling wrapper for ``handle_authorization``."""
+    return handle_authorization(f, spec_template)
 
 
 def get_openapi_meta_data(field_obj: fields.Field) -> dict[str, Any]:
@@ -1001,9 +1057,17 @@ def get_openapi_meta_data(field_obj: fields.Field) -> dict[str, Any]:
 
     openapi_type_info["type"] = type_mapping.get(field_type, "string")
 
+    # Populate example with sensible defaults when none provided
+    if "example" not in openapi_type_info and (example := _resolve_default_example(field_type)):
+        openapi_type_info["example"] = example
+
     if field_type in [fields.DateTime, fields.Date, fields.Time]:
         openapi_type_info["format"] = "date-time" if field_type == fields.DateTime else field_type.__name__.lower()
 
+    if field_type == fields.Decimal and (fmt := field_obj.metadata.get("format")):
+        # Add optional format for Decimal fields if provided in metadata
+        openapi_type_info["format"] = fmt
+
     if field_type == fields.Function:
         openapi_type_info["format"] = "uri"
         openapi_type_info["example"] = "/url/to/resource"
@@ -1020,22 +1084,32 @@ def get_openapi_meta_data(field_obj: fields.Field) -> dict[str, Any]:
 
 
 def get_related_schema_name(field_obj: fields.Field, field_type: type) -> str | None:
-    """Get the related schema name for nested or related fields.
+    """Determine the schema name referenced by a nested or related field.
 
     Args:
-        field_obj (fields.Field): The field to inspect.
-        field_type (type): The type of the field.
+        field_obj (fields.Field): Field instance whose schema is being resolved.
+        field_type (type): Concrete class of ``field_obj`` such as ``Nested``,
+            ``Related`` or ``RelatedList``.
 
     Returns:
-        Optional[str]: The related schema name, if found.
+        str | None: The related schema name converted using
+        ``API_SCHEMA_CASE`` (default ``"camel"``). ``None`` is returned when
+
     """
     if field_type == Nested:
-        return field_obj.schema.__class__.__name__
+        schema_cls = field_obj.schema.__class__
+        model = getattr(schema_cls.Meta, "model", None)
+        name = schema_cls.__name__
     elif field_type in [Related, RelatedList]:
         parent_model = field_obj.parent.Meta.model
         related_model = getattr(parent_model, field_obj.name).property.mapper.class_
-        return f"{related_model.__name__}Schema"
-    return None
+        model = related_model
+        name = f"{related_model.__name__}Schema"
+    else:
+        return None
+
+    case = get_config_or_model_meta("API_SCHEMA_CASE", model=model, default="camel") or "camel"
+    return convert_case(name.replace("Schema", ""), case)
 
 
 def handle_nested_related_fields(
@@ -1044,16 +1118,20 @@ def handle_nested_related_fields(
     related_schema_name: str,
     openapi_type_info: dict[str, Any],
 ) -> dict[str, Any]:
-    """Handle the OpenAPI metadata for nested or related fields.
+    """Populate OpenAPI metadata for nested and related fields.
 
     Args:
-        field_obj (fields.Field): The field to handle.
-        field_type (type): The type of the field.
-        related_schema_name (str): The name of the related schema.
-        openapi_type_info (Dict[str, Any]): The OpenAPI metadata to update.
+        field_obj (fields.Field): Field being processed.
+        field_type (type): Class of ``field_obj``.
+        related_schema_name (str): Name of the referenced schema.
+        openapi_type_info (dict[str, Any]): Existing OpenAPI snippet to
+            mutate.
 
     Returns:
-        Dict[str, Any]: The updated OpenAPI metadata.
+        dict[str, Any]: Updated OpenAPI metadata. When the field represents a
+        collection (``many=True`` or ``RelatedList``), ``type`` is set to
+        ``"array"`` with ``items`` referencing the related schema. Otherwise a
+        direct ``$ref`` is applied.
     """
     if field_obj.many or field_type == RelatedList:
         openapi_type_info["type"] = "array"
@@ -1064,14 +1142,18 @@ def handle_nested_related_fields(
 
 
 def get_description_and_example_add(openapi_type_info: dict[str, Any], field_obj: fields.Field) -> dict[str, Any]:
-    """Add description and example to the OpenAPI metadata from the model field.
+    """Attach description and example metadata defined on a model field.
 
     Args:
-        openapi_type_info (Dict[str, Any]): The OpenAPI metadata to update.
-        field_obj (fields.Field): The Marshmallow field to inspect.
+        openapi_type_info (dict[str, Any]): OpenAPI fragment to enrich.
+        field_obj (fields.Field): Marshmallow field whose underlying SQLAlchemy
+            column may define ``info`` with ``description`` or ``example``
+            entries.
 
     Returns:
-        Dict[str, Any]: The updated OpenAPI metadata.
+        dict[str, Any]: The modified ``openapi_type_info``. If the model field
+        lacks relevant metadata the input is returned unchanged.
+
     """
     model_field = getattr(field_obj.parent.Meta.model, field_obj.name, None)
     if model_field and hasattr(model_field, "info"):
@@ -1087,6 +1169,7 @@ type_mapping = {
     fields.String: "string",
     fields.Integer: "integer",
     fields.Float: "number",
+    fields.Decimal: "number",
     fields.Boolean: "boolean",
     fields.DateTime: "string",
     fields.Date: "string",
@@ -1103,15 +1186,55 @@ type_mapping = {
 }
 
 
-def get_description(kwargs: dict[str, Any]) -> str:
-    """
-    Get the description for the route from the model's Meta class or a default description based on the method.
+example_fallbacks = {
+    fields.Integer: 1,
+    fields.Float: 1.23,
+    fields.Decimal: 9.99,
+    fields.Boolean: True,
+}
+
+
+def _resolve_default_example(field_type: type[fields.Field]) -> Any | None:
+    """Return default example for a field type.
 
     Args:
-        kwargs: Keyword arguments including the model and the method type (GET, POST, etc.).
+        field_type: Marshmallow field class to resolve an example for.
 
     Returns:
-        str: The description string for the route.
+        The configured example value, or ``None`` if no default exists.
+    """
+
+    defaults = example_fallbacks.copy()
+    try:
+        overrides = get_config_or_model_meta("OPENAPI_FIELD_EXAMPLE_DEFAULTS", default={})
+    except RuntimeError:
+        overrides = {}
+    if isinstance(overrides, dict):
+        for key, value in overrides.items():
+            override_cls = getattr(fields, key, None)
+            if isinstance(override_cls, type) and issubclass(override_cls, fields.Field):
+                defaults[override_cls] = value
+    return defaults.get(field_type)
+
+
+def get_description(kwargs: dict[str, Any]) -> str:
+    """Return a human-readable description for an endpoint.
+
+    Args:
+        kwargs (dict[str, Any]): Context options. Recognised keys include:
+            ``model`` or ``child_model`` (type[DeclarativeBase]): Models used to
+                derive the description.
+            ``parent_model`` (type[DeclarativeBase], optional): Required when
+                ``child_model`` is supplied.
+            ``name`` (str): Resource name used in fallback text.
+            ``method`` (str): HTTP method in uppercase.
+            ``multiple`` (bool, optional): Whether the endpoint returns multiple
+                resources. Defaults to ``False``.
+
+    Returns:
+        str: Description sourced from ``model.Meta.description`` or a default
+        string based on ``method``. An empty string is returned when no
+        description can be determined.
     """
     model = kwargs.get("model", kwargs.get("child_model"))
     name, method = kwargs["name"], kwargs["method"]
@@ -1134,14 +1257,14 @@ def get_description(kwargs: dict[str, Any]) -> str:
 
 
 def get_tag_group(kwargs: dict[str, Any]) -> str | None:
-    """
-    Get the x-tagGroup for the route from the model's Meta class.
+    """Retrieve the ``x-tagGroup`` value for a route.
 
     Args:
-        kwargs: Keyword arguments including the model and the method type (GET, POST, etc.).
+        kwargs (dict[str, Any]): Keyword arguments containing ``model`` or
+            ``child_model``.
 
     Returns:
-        str: The tag group string for the route.
+        str | None: Value of ``Meta.tag_group`` if defined; otherwise ``None``.
     """
     model = kwargs.get("model", kwargs.get("child_model"))
     return getattr(model.Meta, "tag_group", None) if hasattr(model, "Meta") else None
@@ -1152,17 +1275,31 @@ def endpoint_namer(
     input_schema: type[Schema] | None = None,
     output_schema: type[Schema] | None = None,
 ) -> str:
-    """
-    Get the endpoint name for the model based on its name.
+    """Generate a pluralised endpoint name for a model.
 
     Args:
-        model (Optional[Type[DeclarativeBase]]): The model to get the endpoint name for.
-        input_schema (Optional[Type[Schema]]): The input schema for the model.
-        output_schema (Optional[Type[Schema]]): The output schema for the model.
+        model (type[DeclarativeBase] | None): Model used to derive the name.
+            This parameter is required; the schema parameters are reserved for
+            future use.
+        input_schema (type[Schema] | None, optional): Unused placeholder to
+            match a common function signature.
+        output_schema (type[Schema] | None, optional): Unused placeholder to
+            match a common function signature.
 
     Returns:
-        str: The endpoint name.
+        str: Endpoint name converted using ``API_ENDPOINT_CASE`` (default
+        ``"kebab"``) and pluralised.
     """
-    case = get_config_or_model_meta("API_ENDPOINT_CASE", default="kebab", model=model)
-    converted_name = convert_case(model.__name__, case)
-    return pluralize_last_word(converted_name)
+    model_obj = model
+    if model_obj is None:
+        schema = input_schema or output_schema
+        model_obj = getattr(getattr(schema, "Meta", None), "model", None) if schema else None
+    if model_obj is None:
+        raise ValueError("A model or schema with a Meta.model attribute is required")
+
+    # Read directly from Flask config to avoid cross-test bleed-through from
+    # model metadata on plain classes. Defaults to kebab-case for endpoints.
+    case = get_config_or_model_meta("API_ENDPOINT_CASE", default="kebab") or "kebab"
+    converted_name = convert_case(model_obj.__name__, case)
+    pluralized_name = pluralize_last_word(converted_name)
+    return convert_case(pluralized_name, case)
