@@ -3,12 +3,15 @@ import os
 import pprint
 import re
 import socket
+from collections.abc import Callable
+from importlib.machinery import ModuleSpec
+from pathlib import Path
 from typing import Any
 from urllib.parse import urlparse
 from xml.etree import ElementTree as ET
 
 import inflect
-from flask import Flask
+from flask import Flask, current_app
 from jinja2 import Environment, FileSystemLoader
 
 from flarchitect.utils.config_helpers import get_config_or_model_meta
@@ -17,10 +20,28 @@ from flarchitect.utils.core_utils import convert_case, get_count
 HTTP_METHODS = ["GET", "POST", "PATCH", "DELETE"]
 DATE_FORMAT = "%Y-%m-%d"
 DATETIME_FORMAT = "%Y-%m-%d %H:%M:%S"
-html_path = ""
 p = inflect.engine()
 
 
+def get_html_path() -> str:
+    """Return the absolute path to the ``html`` templates directory.
+
+    The path is resolved using the registered :class:`~flask.Flask` application
+    when available. If the ``flarchitect`` extension is not registered or no
+    application context is active, the path is determined by searching for an
+    ``html`` folder relative to this file.
+
+    Returns:
+        str: Absolute path to the ``html`` directory. Returns an empty string if
+        the directory cannot be located.
+    """
+
+    try:
+        return current_app.extensions["flarchitect"].get_templates_path()  # type: ignore[index]
+    except Exception:  # pragma: no cover - fallback when app context not available
+        return find_html_directory() or ""
+
+
 class AttributeInitializerMixin:
     """Used for the base Architect flask extension and others
     to initialise their config attributes."""
@@ -58,6 +79,12 @@ class AttributeInitializerMixin:
                 setattr(self, key, kwargs[key])
 
 
+class AttributeInitialiserMixin(AttributeInitializerMixin):
+    """UK spelling alias of :class:`AttributeInitializerMixin`."""
+
+    pass
+
+
 def find_html_directory(starting_directory: str | None = None) -> str | None:
     """Locate the nearest ``html`` directory by searching parent folders.
 
@@ -97,11 +124,19 @@ def manual_render_absolute_template(absolute_template_path: str, **kwargs: Any)
         str: The rendered template as a string.
     """
 
-    template_folder = os.path.join(find_html_directory(), absolute_template_path)
+    template_folder = os.path.join(get_html_path(), absolute_template_path)
     if template_folder.endswith(".html"):
         template_folder, template_filename = os.path.split(template_folder)
 
     env = Environment(loader=FileSystemLoader(template_folder))
+    # ensure standard Flask globals like ``url_for`` are available
+    try:
+        from flask import url_for
+
+        env.globals.update(url_for=url_for)
+    except Exception:  # pragma: no cover - fallback when Flask not installed
+        pass
+
     template = env.get_template(template_filename)
     return template.render(**kwargs)
 
@@ -135,42 +170,60 @@ def find_child_from_parent_dir(parent: str, child: str, current_dir: str = os.ge
     return None
 
 
-def check_rate_prerequisites(service: str) -> None:
-    """
-    Checks if prerequisites for a specific service
-    (e.g., Memcached, Redis) are installed.
+def check_rate_prerequisites(
+    service: str,
+    find_spec: Callable[[str], ModuleSpec | None] = importlib.util.find_spec,
+) -> None:
+    """Verify that dependencies for a cache backend are installed.
 
     Args:
-        service (str): The service to check prerequisites for.
+        service: Name of the cache backend.
+        find_spec: Function used to locate module specifications. Allows tests
+            to supply a stub without monkeypatching.
 
     Raises:
-        ImportError: If the prerequisite is not available.
+        ImportError: If the required client library is missing.
     """
     back_end_spec = "or specify a cache service URI in the flask configuration with the key API_RATE_LIMIT_STORAGE_URI={URL}:{PORT}"
     if service == "Memcached":
-        if importlib.util.find_spec("pymemcache") is None:
+        if find_spec("pymemcache") is None:
             raise ImportError("Memcached prerequisite not available. Please install pymemcache " + back_end_spec)
     elif service == "Redis":
-        if importlib.util.find_spec("redis") is None:
+        if find_spec("redis") is None:
             raise ImportError("Redis prerequisite not available. Please install redis-py " + back_end_spec)
-    elif service == "MongoDB" and importlib.util.find_spec("pymongo") is None:
+    elif service == "MongoDB" and find_spec("pymongo") is None:
         raise ImportError("MongoDB prerequisite not available. Please install pymongo " + back_end_spec)
 
 
-def check_rate_services() -> str | None:
-    """
-    Checks if any supported services (Memcached, Redis, MongoDB)
-    are running locally and returns their URI.
+def check_rate_services(
+    config_getter: Callable[[str, Any, Any], Any] = get_config_or_model_meta,
+    prereq_checker: Callable[[str], None] = check_rate_prerequisites,
+    socket_factory: Callable[..., socket.socket] = socket.socket,
+) -> str | None:
+    """Return the configured or automatically detected rate limit backend.
+
+    Args:
+        config_getter: Function used to obtain configuration values.
+        prereq_checker: Callable used to validate backend prerequisites.
+        socket_factory: Factory returning socket-like objects. Facilitates
+            dependency injection for tests without monkeypatching.
+
+    The function accepts explicitly configured cache URIs and validates that the
+    scheme corresponds to a supported backend. ``memory://`` is permitted without
+    a host component. If no configuration is provided, the function attempts to
+    detect running local services for Memcached, Redis, or MongoDB and returns
+    the appropriate URI.
 
     Returns:
-        Optional[str]: The URI of the running service, or None if no service is found.
+        Optional[str]: The URI of the running service, or ``None`` if no service
+        is found.
     """
     services = {
         "Memcached": 11211,
         "Redis": 6379,
         "MongoDB": 27017,
     }
-    uri = get_config_or_model_meta("API_RATE_LIMIT_STORAGE_URI", default=None)
+    uri = config_getter("API_RATE_LIMIT_STORAGE_URI", default=None)
     if uri:
         parsed = urlparse(uri)
         scheme_map = {
@@ -179,30 +232,44 @@ def check_rate_services() -> str | None:
             "mongodb": "MongoDB",
             "memory": None,
         }
+        if not parsed.scheme:
+            raise ValueError("Rate limit storage URI must include a scheme")
         if parsed.scheme not in scheme_map:
             raise ValueError(f"Unsupported rate limit storage backend: {parsed.scheme}")
+        # In-memory backends do not require a network location. All others do.
+        if parsed.scheme != "memory" and not parsed.netloc:
+            raise ValueError("Rate limit storage URI must include a host")
         service_name = scheme_map[parsed.scheme]
         if service_name:
-            check_rate_prerequisites(service_name)
+            prereq_checker(service_name)
         return uri
 
+    # Allow disabling auto-detection in constrained environments (e.g. sandboxes/CI)
+    if config_getter("API_RATE_LIMIT_AUTODETECT", default=True) is False:
+        return None
+
     for service, port in services.items():
-        s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
-        s.settimeout(1)
         try:
-            s.connect(("127.0.0.1", port))
-            s.close()
-            check_rate_prerequisites(service)
+            sock = socket_factory(socket.AF_INET, socket.SOCK_STREAM)
+            sock.settimeout(1)
+            try:
+                sock.connect(("127.0.0.1", port))
+                sock.close()
+                prereq_checker(service)
 
-            rate_type = {
-                "Memcached": f"memcached://127.0.0.1:{port}",
-                "Redis": f"redis://127.0.0.1:{port}",
-                "MongoDB": f"mongodb://127.0.0.1:{port}",
-            }
-            return rate_type[service]
+                rate_type = {
+                    "Memcached": f"memcached://127.0.0.1:{port}",
+                    "Redis": f"redis://127.0.0.1:{port}",
+                    "MongoDB": f"mongodb://127.0.0.1:{port}",
+                }
+                return rate_type[service]
 
-        except OSError:
-            continue
+            except OSError:
+                # Nothing listening on this port; try the next service
+                continue
+        except PermissionError:
+            # Sockets disabled by the runtime (e.g. sandbox). Fall back to in-memory.
+            return None
 
     return None
 
@@ -237,20 +304,32 @@ def search_all_keys(model: Any, key: str) -> bool:
     return any(any(get_config_or_model_meta(key, model=subclass, method=method) for method in HTTP_METHODS) for subclass in model.__subclasses__())
 
 
-def generate_readme_html(file_path: str, *args: Any, **kwargs: Any) -> str:
+def generate_readme_html(file_path: str | Path, *args: Any, **kwargs: Any) -> str:
     """Generate README content from a Jinja2 template.
 
     Args:
-        file_path (str): The path to the Jinja2 template file.
-        *args (Any): Variable length argument list.
-        **kwargs (Any): Arbitrary keyword arguments.
+        file_path: Path to the Jinja2 template file. Relative paths are
+            resolved from the project root.
+        *args: Variable length argument list passed to ``render``.
+        **kwargs: Arbitrary keyword arguments passed to ``render``.
 
     Returns:
-        str: The rendered content as a string.
+        Rendered template content.
+
+    Raises:
+        FileNotFoundError: If ``file_path`` does not exist.
     """
-    template_dir, template_file = os.path.split(file_path)
-    environment = Environment(loader=FileSystemLoader(os.path.abspath(template_dir)))
-    template = environment.get_template(template_file)
+    path = Path(file_path)
+    if not path.is_absolute():
+        # Resolve relative paths from the project root to avoid dependence on
+        # the current working directory during test execution.
+        path = Path(__file__).resolve().parents[2] / path
+
+    if not path.exists():
+        raise FileNotFoundError(f"{path} not found.")
+
+    environment = Environment(loader=FileSystemLoader(str(path.parent)))
+    template = environment.get_template(path.name)
     return template.render(*args, **kwargs)
 
 
@@ -317,7 +396,8 @@ def make_base_dict() -> dict[str, Any]:
         Dict[str, Any]: The base dictionary with configuration settings.
     """
     output = {"value": "..."}
-    field_case = get_config_or_model_meta("API_FIELD_CASE", default="snake_case")
+    # Default to 'snake' which is recognised by convert_case
+    field_case = get_config_or_model_meta("API_FIELD_CASE", default="snake")
 
     config_options = [
         ("API_DUMP_DATETIME", "datetime", "2024-01-01T00:00:00.0000+00:00"),
@@ -327,8 +407,8 @@ def make_base_dict() -> dict[str, Any]:
             get_config_or_model_meta("API_VERSION", default=True),
         ),
         ("API_DUMP_STATUS_CODE", "status_code", 200),
-        ("API_DUMP_RESPONSE_TIME", "response_ms", 15),
-        ("API_DUMP_COUNT", "total_count", 10),
+        ("API_DUMP_RESPONSE_MS", "response_ms", 15),
+        ("API_DUMP_TOTAL_COUNT", "total_count", 10),
         ("API_DUMP_NULL_NEXT_URL", "next_url", "/api/example/url"),
         ("API_DUMP_NULL_PREVIOUS_URL", "previous_url", "null"),
         ("API_DUMP_NULL_ERRORS", "errors", "null", False),
