@@ -1,9 +1,8 @@
 import time
 from collections.abc import Callable
-from datetime import datetime
+from datetime import datetime, timezone
 from typing import Any
 
-import pytz
 from flask import Response, current_app, g, jsonify
 
 from flarchitect.utils.config_helpers import get_config_or_model_meta, is_xml
@@ -22,7 +21,7 @@ def create_response(
     response_ms: float | None = None,
     result: Any | None = None,
 ) -> Response:
-    """Create a standardized Flask :class:`~flask.Response`.
+    """Create a standardised Flask :class:`~flask.Response`.
 
     Args:
         value (Optional[Any]): The value to be returned.
@@ -37,12 +36,12 @@ def create_response(
 
     Notes:
         If the application configuration defines ``API_FINAL_CALLBACK`` it will
-        be invoked with the assembled response payload prior to serialization.
+        be invoked with the assembled response payload prior to serialisation.
         This allows custom mutation of the outgoing data, such as injecting
         additional metadata.
 
     Returns:
-        Response: A standardized response object.
+        Response: A standardised response object.
     """
     if result is not None:
         from flarchitect.utils.responses import CustomResponse
@@ -55,7 +54,11 @@ def create_response(
             value, count = value_dict.get("query", value_dict), get_count(value_dict, value_dict.get("query"))
             next_url, previous_url = value_dict.get("next_url"), value_dict.get("previous_url")
         elif isinstance(value, CustomResponse):
-            next_url, previous_url, count = value.next_url, value.previous_url, value.count
+            next_url, previous_url, count = (
+                value.next_url,
+                value.previous_url,
+                value.count,
+            )
         errors = None if status < HTTP_BAD_REQUEST else value
         if errors:
             value = None
@@ -66,7 +69,12 @@ def create_response(
         # error responses were missing this. Added here to ensure it's always present.
         response_ms = round((time.time() - g.start_time) * 1000, 0) if g.get("start_time") else "n/a"
 
-    current_time_with_tz = datetime.now(pytz.utc).isoformat()
+    current_time_with_tz = datetime.now(timezone.utc).isoformat()
+    # Best-effort request id from Flask context (set by Architect.before_request)
+    try:
+        request_id = getattr(g, "request_id", None)
+    except Exception:
+        request_id = None
     data = {
         "api_version": current_app.config.get("API_VERSION"),
         "datetime": current_time_with_tz,
@@ -78,14 +86,18 @@ def create_response(
         "next_url": next_url,
         "previous_url": previous_url,
     }
+    # Only add when available; filtering controls visibility by config
+    if request_id:
+        data["request_id"] = request_id
 
     data = _filter_response_data(data)
-    data = {convert_case(k, get_config_or_model_meta("API_FIELD_CASE", default="snake_case")): v for k, v in data.items()}
+    # Default to 'snake' to match supported case values
+    data = {convert_case(k, get_config_or_model_meta("API_FIELD_CASE", default="snake")): v for k, v in data.items()}
 
     # Optional hook allowing applications to post-process the outgoing payload.
     # ``API_FINAL_CALLBACK`` should be a callable that accepts the response
     # dictionary and returns the modified dictionary. This can be used to inject
-    # custom metadata or otherwise mutate the payload before serialization.
+    # custom metadata or otherwise mutate the payload before serialisation.
     final_callback: Callable[[dict[str, Any]], dict[str, Any]] | None = get_config_or_model_meta("API_FINAL_CALLBACK")
     if final_callback:
         data = final_callback(data)
