@@ -1,8 +1,25 @@
-import pytest
+import importlib.util
+import sys
+from pathlib import Path
+from unittest.mock import patch
 
-from demo.basic_factory.basic_factory import create_app
-from demo.model_extension.model import create_app as create_app_models
-from demo.soft_delete.soft_delete import create_app as create_app_soft
+import pytest
+from flask import Flask
+
+module_path = Path(__file__).resolve().parents[1] / "flarchitect" / "utils" / "config_helpers.py"
+spec = importlib.util.spec_from_file_location("config_helpers", module_path)
+config_helpers = importlib.util.module_from_spec(spec)
+sys.modules[spec.name] = config_helpers
+assert spec.loader is not None
+spec.loader.exec_module(config_helpers)
+get_config_or_model_meta = config_helpers.get_config_or_model_meta
+
+try:  # pragma: no cover - optional imports for full test suite
+    from demo.basic_factory.basic_factory import create_app
+    from demo.model_extension.model import create_app as create_app_models
+    from demo.soft_delete.soft_delete import create_app as create_app_soft
+except ModuleNotFoundError:  # pragma: no cover - allow minimal environments
+    create_app = create_app_models = create_app_soft = None
 
 
 @pytest.fixture
@@ -23,9 +40,19 @@ def client(app):
     return app.test_client()
 
 
+# ensure no extra context is pushed when already active
+def test_search_in_flask_config_no_extra_context() -> None:
+    """Ensure search_in_flask_config avoids pushing a new app context."""
+    app = Flask(__name__)
+    app.config["API_TITLE"] = "Automated test"
+    with app.app_context(), patch.object(app, "app_context", wraps=app.app_context) as mock_ctx:
+        assert get_config_or_model_meta("api_title") == "Automated test"
+        mock_ctx.assert_not_called()
+
+
 # check to make sure that the title and version are changed
 def test_basic_change_title_and_version(client):
-    response = client.get("/swagger.json")
+    response = client.get("/apispec.json")
 
     assert response.json["info"]["title"] == "Automated test"
     assert response.json["info"]["version"] == "0.2.0"
@@ -36,6 +63,20 @@ def test_basic_change_title_and_version(client):
     assert "0.2.0" in html
 
 
+def test_hidden_patch_and_auto_schemas(client) -> None:
+    """Ensure patch and auto schemas are excluded from OpenAPI docs."""
+    swagger = client.get("/swagger.json").json
+    schema_names = swagger["components"]["schemas"].keys()
+    assert "auto" not in schema_names
+    assert all(not name.startswith("patch") for name in schema_names)
+
+    for methods in swagger["paths"].values():
+        patch_spec = methods.get("patch")
+        if patch_spec:
+            ref = patch_spec["requestBody"]["content"]["application/json"]["schema"]["$ref"]
+            assert "patch" not in ref.lower()
+
+
 @pytest.fixture
 def app_meth():
     app_new = create_app(
@@ -120,7 +161,7 @@ def test_change_spec_description_and_others():
     )
 
     client = app.test_client()
-    resp = client.get("/swagger.json")
+    resp = client.get("/apispec.json")
 
     assert resp.json["info"]["description"] == "This is a test description"
     assert resp.json["info"]["x-logo"]["url"] == "http://test.com/logo.png"
@@ -155,9 +196,7 @@ def test_read_only():
 
 # check to make sure that changing the docs url works
 def test_docs_path():
-    app = create_app(
-        {"API_DOCUMENTATION_URL": "/my_docs", "API_TITLE": "Change docs url"}
-    )
+    app = create_app({"API_DOCUMENTATION_URL": "/my_docs", "API_TITLE": "Change docs url"})
 
     client = app.test_client()
     resp = client.get("/my_docs")
@@ -186,7 +225,7 @@ def test_docs_extra_info():
     )
 
     client = app.test_client()
-    resp = client.get("/swagger.json")
+    resp = client.get("/apispec.json")
 
     assert resp.json["info"]["contact"] == {
         "email": "help@test.com",
@@ -207,22 +246,22 @@ def test_docs_extra_info():
 def test_basic_no_change_api_output(client):
     books = client.get("/api/books").json
 
-    assert "datetime" in books.keys()
-    assert "api_version" in books.keys()
-    assert "status_code" in books.keys()
-    assert "total_count" in books.keys()
-    assert "next_url" in books.keys()
-    assert "previous_url" in books.keys()
+    assert "datetime" in books
+    assert "api_version" in books
+    assert "status_code" in books
+    assert "total_count" in books
+    assert "next_url" in books
+    assert "previous_url" in books
 
     books_error = client.get("/api/books/0009999").json
-    assert "errors" in books_error.keys()
+    assert "errors" in books_error
 
     book = client.get("/api/books/1").json
 
-    assert "datetime" in book.keys()
-    assert "api_version" in book.keys()
-    assert "status_code" in book.keys()
-    assert "total_count" in book.keys()
+    assert "datetime" in book
+    assert "api_version" in book
+    assert "status_code" in book
+    assert "total_count" in book
 
 
 # make sure camel case is and isn't used.
@@ -236,13 +275,13 @@ def test_change_to_camel_output():
     )
     client_camel = app_cam.test_client()
     book = client_camel.get("/api/books/1").json
-    assert "publication_date" in book["value"].keys()
+    assert "publication_date" in book["value"]
 
     api_calls = client_camel.get("/api/api-calls").json
     assert api_calls["status_code"] == 200
 
-    swagger_oas = client_camel.get("/swagger.json").json
-    assert "apiCalls" in swagger_oas["components"]["schemas"].keys()
+    swagger_oas = client_camel.get("/apispec.json").json
+    assert "apiCalls" in swagger_oas["components"]["schemas"]
 
 
 def test_change_to_pascal_output():
@@ -256,13 +295,13 @@ def test_change_to_pascal_output():
     client_pascal = app_pascal.test_client()
 
     book = client_pascal.get("/api/books/1").json
-    assert "publication-date" in book["value"].keys()
+    assert "publication-date" in book["value"]
 
     apiCalls = client_pascal.get("/api/api_calls").json
     assert apiCalls["status-code"] == 200
 
-    swaggerOas = client_pascal.get("/swagger.json").json
-    assert "ApiCalls" in swaggerOas["components"]["schemas"].keys()
+    swaggerOas = client_pascal.get("/apispec.json").json
+    assert "ApiCalls" in swaggerOas["components"]["schemas"]
 
 
 def test_change_to_snake_output():
@@ -276,13 +315,13 @@ def test_change_to_snake_output():
     client_snake = app_snake.test_client()
 
     book = client_snake.get("/api/books/1").json
-    assert "PublicationDate" in book["Value"].keys()
+    assert "PublicationDate" in book["Value"]
 
     api_calls = client_snake.get("/api/apiCalls").json
     assert api_calls["StatusCode"] == 200
 
-    swagger_oas = client_snake.get("/swagger.json").json
-    assert "api_calls" in swagger_oas["components"]["schemas"].keys()
+    swagger_oas = client_snake.get("/apispec.json").json
+    assert "api_calls" in swagger_oas["components"]["schemas"]
 
 
 def test_change_to_screaming_snake_output():
@@ -296,13 +335,13 @@ def test_change_to_screaming_snake_output():
     client_screaming_snake = app_screaming_snake.test_client()
 
     book = client_screaming_snake.get("/api/books/1").json
-    assert "publicationDate" in book["value"].keys()
+    assert "publicationDate" in book["value"]
 
     api_calls = client_screaming_snake.get("/api/api-calls").json
     assert api_calls["statusCode"] == 200
 
-    swagger_oas = client_screaming_snake.get("/swagger.json").json
-    assert "API_CALLS" in swagger_oas["components"]["schemas"].keys()
+    swagger_oas = client_screaming_snake.get("/apispec.json").json
+    assert "API_CALLS" in swagger_oas["components"]["schemas"]
 
 
 def test_change_to_kebab_output():
@@ -316,13 +355,13 @@ def test_change_to_kebab_output():
     client_kebab = app_kebab.test_client()
 
     book = client_kebab.get("/api/Books/1").json
-    assert "publication_date" in book["value"].keys()
+    assert "publication_date" in book["value"]
 
     api_calls = client_kebab.get("/api/ApiCalls").json
     assert api_calls["status_code"] == 200
 
-    swagger_oas = client_kebab.get("/swagger.json").json
-    assert "api-calls" in swagger_oas["components"]["schemas"].keys()
+    swagger_oas = client_kebab.get("/apispec.json").json
+    assert "api-calls" in swagger_oas["components"]["schemas"]
 
 
 def test_dump_hybrid_off():
@@ -336,14 +375,14 @@ def test_dump_hybrid_off():
     dump_client = dump_app.test_client()
     resp = dump_client.get("/api/authors/1")
 
-    assert "full_name" not in resp.json["value"].keys()
+    assert "full_name" not in resp.json["value"]
     assert resp.status_code == 200
 
 
 def test_dump_hybrid_on(client):
     resp = client.get("/api/authors/1")
 
-    assert "full_name" in resp.json["value"].keys()
+    assert "full_name" in resp.json["value"]
 
 
 # change the api base url prefix
@@ -357,7 +396,7 @@ def test_change_api_route():
     book = client_prefix.get("/my_api/books/1")
 
     assert book.status_code == 200
-    assert "title" in book.json["value"].keys()
+    assert "title" in book.json["value"]
 
 
 # change the api base output
@@ -442,7 +481,7 @@ def test_switch_off_url_params():
     app_filters = create_app(
         {
             "API_ALLOW_ORDER_BY": False,
-            "API_ALLOW_FILTER": False,
+            "API_ALLOW_FILTERS": False,
             "API_ALLOW_SELECT_FIELDS": False,
         }
     )
@@ -456,7 +495,7 @@ def test_switch_off_url_params():
     assert resp.status_code == 200
     assert 21 not in [x["id"] for x in resp_order.json["value"]]
     assert resp_filter.json["value"][0]["id"] == 1
-    assert "created" in resp_select.json["value"][0].keys()
+    assert "created" in resp_select.json["value"][0]
 
 
 def test_rate_limit():
@@ -475,7 +514,7 @@ def test_disable_docs():
     app_docs = create_app({"API_CREATE_DOCS": False})
     client_docs = app_docs.test_client()
     docs = client_docs.get("/docs")
-    swagger = client_docs.get("/swagger.json")
+    swagger = client_docs.get("/apispec.json")
     books = client_docs.get("/api/books")
 
     assert docs.status_code == 404
@@ -504,7 +543,7 @@ def client_one(app_one):
 
 def test_show_underscore_attributes(client_one):
     authors_response = client_one.get("/api/authors").json
-    assert "_hiddenField" in authors_response["value"][0].keys()
+    assert "_hidden_field" in authors_response["value"][0]
 
 
 def test_cascade_delete(client_one):
@@ -512,7 +551,7 @@ def test_cascade_delete(client_one):
     author_id = authors[0]["id"]
 
     response = client_one.delete(f"/api/authors/{author_id}")
-    assert response.status_code == 500
+    assert response.status_code == 409
 
 
 hooks = {
@@ -646,15 +685,15 @@ def client_three(app_three):
 
 def test_hide_underscore_attributes(client_two):
     authors_response = client_two.get("/api/authors").json
-    assert "_hiddenField" not in authors_response["value"][0].keys()
+    assert "_hiddenField" not in authors_response["value"][0]
 
 
-def test_show_underscore_attributes(client_two):
+def test_show_underscore_attributes_with_override(client_two):
     app_under = create_app_models({"API_IGNORE_UNDERSCORE_ATTRIBUTES": False})
     client_under = app_under.test_client()
 
     authors_response = client_under.get("/api/authors").json
-    assert "_hidden_field" in authors_response["value"][0].keys()
+    assert "_hidden_field" in authors_response["value"][0]
 
 
 def test_callbacks(client_two):
@@ -664,7 +703,7 @@ def test_callbacks(client_two):
 
     del book_one["id"]
     client_two.post("/api/books", json=book_one).json["value"]
-    client_two.get("/api/books/9999999").json
+    client_two.get("/api/books/9999999")
     client_two.patch("/api/books/" + str(id_key), json=book_one).json["value"]
     global hooks
     assert hooks.get("setup_hook")
@@ -678,27 +717,23 @@ def test_callbacks(client_two):
 
 
 def test_global_query_param(client_two):
-    swagger = client_two.get("/swagger.json").json
+    swagger = client_two.get("/apispec.json").json
 
     params = [x["name"] for x in swagger["paths"]["/api/books"]["get"]["parameters"]]
     assert "log" in params
 
 
 def test_post_specific_query_param(client_two):
-    swagger = client_two.get("/swagger.json").json
+    swagger = client_two.get("/apispec.json").json
 
-    post_params = [
-        x["name"] for x in swagger["paths"]["/api/books"]["post"]["parameters"]
-    ]
-    get_params = [
-        x["name"] for x in swagger["paths"]["/api/books"]["get"]["parameters"]
-    ]
+    post_params = [x["name"] for x in swagger["paths"]["/api/books"]["post"]["parameters"]]
+    get_params = [x["name"] for x in swagger["paths"]["/api/books"]["get"]["parameters"]]
 
     assert "log_one" in post_params
     assert "log_one" not in get_params
 
 
-def test_cascade_delete(client_two):
+def test_cascade_delete_enabled(client_two):
     app_cascade_delete = create_app_models(
         {
             "API_ALLOW_CASCADE_DELETE": True,
@@ -706,13 +741,11 @@ def test_cascade_delete(client_two):
     )
     client_cascade_delete = app_cascade_delete.test_client()
 
-    books = client_cascade_delete.get("/api/authors/1/books").json["value"]
+    client_cascade_delete.get("/api/authors/1/books")
     delete_response = client_cascade_delete.delete("/api/authors/1")
-    delete_response.status_code == 409
+    assert delete_response.status_code == 409
     assert "cascade_delete=1" in delete_response.json["errors"]["error"]
-    delete_response_happy = client_cascade_delete.delete(
-        "/api/authors/1?cascade_delete=1"
-    )
+    delete_response_happy = client_cascade_delete.delete("/api/authors/1?cascade_delete=1")
     assert delete_response_happy.status_code == 200
 
 
