@@ -3,29 +3,23 @@ from datetime import datetime, timedelta
 
 import numpy as np
 
-from demo.model_extension.model.models import (
-    Author,
-    Book,
-    Category,
-    Publisher,
-    Review,
-)
+from demo.model_extension.model.models import Author, Book, Category, Publisher, Review
 
 categories = {
     "Fantasy": "Features magical elements, mythical creatures, and imaginary worlds.",
     "Science Fiction": "Explores futuristic concepts, advanced technology, and often space exploration.",
     "Mystery": "Involves suspenseful and puzzling scenarios, often with a detective or investigator.",
     "Thriller": "Focuses on generating excitement and suspense, with high stakes and constant tension.",
-    "Romance": "Centers on love stories and romantic relationships between characters.",
+    "Romance": "Centres on love stories and romantic relationships between characters.",
     "Historical Fiction": "Set in the past, blending historical facts with fictional characters and plots.",
     "Horror": "Aimed to scare, unsettle, or horrify the reader, often with supernatural elements.",
-    "Literary Fiction": "Emphasizes themes, character development, and stylistic complexity over plot.",
+    "Literary Fiction": "Emphasises themes, character development, and stylistic complexity over plot.",
     "Young Adult": "Targets teenagers and young adults, dealing with themes relevant to youth.",
     "Children's Books": "Designed for young readers, featuring stories and illustrations suitable for children.",
     "Biography": "A detailed account of a person's life, told by someone else.",
     "Self-Help": "Intended to guide readers in personal improvement and tackling personal problems.",
     "Cookbooks": "A collection of recipes and cooking tips, often accompanied by culinary guidance.",
-    "Poetry": "Expressive writing, often employing verse, meter, and imagery for emotional impact.",
+    "Poetry": "Expressive writing, often employing verse, metre, and imagery for emotional impact.",
     "Graphic Novels": "Narrative works in which the story is conveyed through sequential art.",
 }
 
@@ -34,7 +28,7 @@ good_words = [
     "wonderful",
     "exciting",
     "delightful",
-    "marvelous",
+    "marvellous",
     "superb",
     "enjoyable",
     "splendid",
@@ -61,7 +55,7 @@ bad_words = [
     "horrible",
     "tedious",
     "miserable",
-    "lackluster",
+    "lacklustre",
     "uninspiring",
     "disappointing",
 ]
@@ -145,46 +139,28 @@ last_names = [
     "Turner",
 ]
 
-nationality = (
-    ["English"] * 10
-    + ["Scottish"] * 10
-    + ["Welsh"] * 10
-    + ["Irish"] * 5
-    + ["American"] * 3
-    + ["Australian"] * 3
-)
+nationality = ["English"] * 10 + ["Scottish"] * 10 + ["Welsh"] * 10 + ["Irish"] * 5 + ["American"] * 3 + ["Australian"] * 3
 
 bios = [
-    "Renowned for their vivid storytelling, this author has captivated readers worldwide with their imaginative "
-    "narratives.",
-    "With a unique voice that resonates across genres, this writer has consistently been at the forefront of literary "
-    "innovation.",
+    "Renowned for their vivid storytelling, this author has captivated readers worldwide with their imaginative narratives.",
+    "With a unique voice that resonates across genres, this writer has consistently been at the forefront of literary innovation.",
     "An acclaimed master of character development, their books offer deep insights into the human condition.",
-    "Known for their suspenseful plots and unexpected twists, this author has become a staple for thrill-seekers and "
-    "mystery lovers alike.",
-    "Their elegant prose and poetic descriptions have earned them a distinguished place among contemporary literary "
-    "figures.",
-    "With a keen eye for detail, this writer crafts immersive worlds that transport readers to different times and "
-    "places.",
+    "Known for their suspenseful plots and unexpected twists, this author has become a staple for thrill-seekers and mystery lovers alike.",
+    "Their elegant prose and poetic descriptions have earned them a distinguished place among contemporary literary figures.",
+    "With a keen eye for detail, this writer crafts immersive worlds that transport readers to different times and places.",
     "A trailblazer in their genre, they have garnered numerous awards and accolades for their groundbreaking work.",
-    "Their compelling narratives and complex characters reflect a profound understanding of social and cultural "
-    "dynamics.",
-    "This author's ability to weave humor and wit into their storytelling has delighted audiences, making their books "
-    "a joy to read.",
+    "Their compelling narratives and complex characters reflect a profound understanding of social and cultural dynamics.",
+    "This author's ability to weave humour and wit into their storytelling has delighted audiences, making their books a joy to read.",
     "A champion of exploring challenging themes, their works are known for their depth and thought-provoking content.",
-    "Blending rich imagination with intricate plots, this author creates captivating tales that linger in the minds"
-    " of readers.",
-    "Known for their eloquent narrative style, their books explore the nuances of everyday life with grace and"
-    " sensitivity.",
+    "Blending rich imagination with intricate plots, this author creates captivating tales that linger in the minds of readers.",
+    "Known for their eloquent narrative style, their books explore the nuances of everyday life with grace and sensitivity.",
     "With a flair for bringing characters to life, their stories resonate with readers, evoking a range of emotions.",
     "Their work stands out for its lyrical quality, turning even the most mundane scenarios into something magical.",
-    "Masterfully constructing complex relationships in their narratives, this writer reveals the multifaceted nature"
-    " of human connections.",
+    "Masterfully constructing complex relationships in their narratives, this writer reveals the multifaceted nature of human connections.",
     "Renowned for crafting compelling dialogues, they bring authenticity and depth to each character they create.",
     "Their storytelling transcends boundaries, appealing to a diverse and broad audience with its universal themes.",
     "Expertly intertwining multiple storylines, they create rich tapestries that capture the complexity of life.",
-    "Their attention to emotional detail makes each novel a deeply moving experience, inviting readers to reflect"
-    " on their own lives.",
+    "Their attention to emotional detail makes each novel a deeply moving experience, inviting readers to reflect on their own lives.",
     "With a gift for observation, their books offer insightful perspectives on everyday experiences and encounters.",
 ]
 
@@ -324,9 +300,7 @@ def generate_title() -> str:
     theme = random.choice(themes)
 
     # Replace placeholders with actual words
-    title = (
-        pattern.replace("[adj]", adj).replace("[noun]", noun).replace("[theme]", theme)
-    )
+    title = pattern.replace("[adj]", adj).replace("[noun]", noun).replace("[theme]", theme)
 
     return title
 
@@ -392,19 +366,20 @@ def generate_company_name() -> str:
     return random.choice(patterns)
 
 
-def generate_random_year(start=1860, to=datetime.now().year) -> int:
-    """
-    Generates a random year between 1940 and the current year.
+def generate_random_year(start: int = 1860, end: int | None = None) -> int:
+    """Generate a random year between ``start`` and ``end``.
 
     Args:
-        start (int, optional): The minimum year to generate. Defaults to None.
+        start: The minimum year to generate.
+        end: The maximum year to generate. Defaults to current year if ``None``.
 
     Returns:
-        int: Random year.
-
+        Randomly selected year within the given range.
     """
 
-    return random.randint(start, to)
+    if end is None:
+        end = datetime.now().year
+    return random.randint(start, end)
 
 
 def random_ratings():
@@ -468,10 +443,7 @@ def create_reviews(db, books):
             if rating >= 5:
                 review_text = f"{book.author.full_name} has done an {random.choice(good_words)} job with this book. {random.choice(recommendations)}"
             else:
-                review_text = (
-                    f"{book.author.full_name} has done an {random.choice(good_words)} job with this book. {negative_reviews}"
-                    f""
-                )
+                review_text = f"{book.author.full_name} has done an {random.choice(good_words)} job with this book. {negative_reviews}"
 
             review = Review(
                 rating=rating,
@@ -503,7 +475,7 @@ def create_books(db, authors, categories, publishers):
     for author in authors:
         author_categories = []
         publisher = random.choice(publishers)
-        for x in range(0, random.randint(1, 3)):
+        for _ in range(random.randint(1, 3)):
             author_categories.append(random.choice(categories))
             author_categories = list(set(author_categories))
 
@@ -511,9 +483,7 @@ def create_books(db, authors, categories, publishers):
             categories = random.choices(author_categories)
             isbn = make_isbn()
             title = generate_title()
-            publication_year = generate_random_year(
-                author.date_of_birth.year + 20, datetime.now().year
-            )
+            publication_year = generate_random_year(author.date_of_birth.year + 20, datetime.now().year)
 
             publication_date = datetime(
                 year=publication_year,
@@ -587,11 +557,9 @@ def create_publishers(db):
 
     publishers = []
 
-    for x in range(0, 30):
+    for _ in range(30):
         name = generate_company_name()
-        website = (
-            "https://" + name.replace(" ", "").replace("&", "and").lower() + ".co.uk"
-        )
+        website = "https://" + name.replace(" ", "").replace("&", "and").lower() + ".co.uk"
         foundation_year = generate_random_year(1860, 1920)
 
         company = Publisher(name=name, website=website, foundation_year=foundation_year)
@@ -627,7 +595,7 @@ def create_authors(db):
 
     authors = []
 
-    for x in range(0, 60):
+    for _ in range(60):
         first_name, last_name = get_name()
         website = "https://" + (first_name + last_name).lower() + ".co.uk"
         rand_nationality = random.choice(nationality)
